@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -76,7 +76,7 @@ public class AuditProviderFactory {
 	private boolean mInitDone = false;
 	private JVMShutdownHook jvmShutdownHook = null;
 
-	private AuditProviderFactory() {
+	public AuditProviderFactory() {
 		LOG.info("AuditProviderFactory: creating..");
 
 		mProvider = getDefaultProvider();
@@ -96,11 +96,7 @@ public class AuditProviderFactory {
 		return ret;
 	}
 
-	public static AuditHandler getAuditProvider() {
-		return AuditProviderFactory.getInstance().getProvider();
-	}
-
-	public AuditHandler getProvider() {
+	public AuditHandler getAuditProvider() {
 		return mProvider;
 	}
 
