@@ -45,6 +45,10 @@ public interface RangerPolicyEngine {
 
 	void setTrustedProxyAddresses(String[] trustedProxyAddresses);
 
+	boolean getUseForwardedIPAddress();
+
+	String[] getTrustedProxyAddresses();
+
     RangerServiceDef getServiceDef();
 
     long getPolicyVersion();
@@ -57,6 +61,8 @@ public interface RangerPolicyEngine {
 
 	Collection<RangerAccessResult> evaluatePolicies(Collection<RangerAccessRequest> requests, int policyType, RangerAccessResultProcessor resultProcessor);
 
+	RangerResourceACLs getResourceACLs(RangerAccessRequest request);
+
 	boolean preCleanup();
 
 	void cleanup();
@@ -67,12 +73,16 @@ public interface RangerPolicyEngine {
 
 	boolean isAccessAllowed(Map<String, RangerPolicyResource> resources, String user, Set<String> userGroups, String accessType);
 
+	boolean isAccessAllowed(RangerPolicy policy, String user, Set<String> userGroups, String accessType);
+
 	List<RangerPolicy> getExactMatchPolicies(RangerAccessResource resource, Map<String, Object> evalContext);
 
 	List<RangerPolicy> getExactMatchPolicies(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext);
 
 	List<RangerPolicy> getMatchingPolicies(RangerAccessResource resource);
 
+	List<RangerPolicy> getMatchingPolicies(RangerAccessRequest request);
+
 	RangerResourceAccessInfo getResourceAccessInfo(RangerAccessRequest request);
 
 	List<RangerPolicy> getAllowedPolicies(String user, Set<String> userGroups, String accessType);
