@@ -31,6 +31,7 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
+import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator.PolicyACLSummary;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
 import org.apache.ranger.plugin.util.RangerPerfTracer;
@@ -39,11 +40,15 @@ import org.apache.ranger.plugin.util.ServicePolicies;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Date;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import static org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator.ACCESS_CONDITIONAL;
+
 public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 	private static final Log LOG = LogFactory.getLog(RangerPolicyEngineImpl.class);
 
@@ -53,6 +58,7 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 	private static final Log PERF_CONTEXTENRICHER_REQUEST_LOG = RangerPerfTracer.getPerfLogger("contextenricher.request");
 	private static final Log PERF_POLICYENGINE_REBALANCE_LOG = RangerPerfTracer.getPerfLogger("policyengine.rebalance");
 	private static final Log PERF_POLICYENGINE_USAGE_LOG = RangerPerfTracer.getPerfLogger("policyengine.usage");
+	private static final Log PERF_POLICYENGINE_GET_ACLS_LOG = RangerPerfTracer.getPerfLogger("policyengine.getResourceACLs");
 
 	private static final int MAX_POLICIES_FOR_CACHE_TYPE_EVALUATOR = 100;
 
@@ -193,6 +199,16 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		this.trustedProxyAddresses = trustedProxyAddresses;
 	}
 
+	@Override
+	public boolean getUseForwardedIPAddress() {
+		return useForwardedIPAddress;
+	}
+
+	@Override
+	public String[] getTrustedProxyAddresses() {
+		return trustedProxyAddresses;
+	}
+
 	@Override
 	public RangerServiceDef getServiceDef() {
 		return policyRepository.getServiceDef();
@@ -324,6 +340,136 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		return ret;
 	}
 
+	@Override
+	public RangerResourceACLs getResourceACLs(RangerAccessRequest request) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerPolicyEngineImpl.getResourceACLs(request=" + request + ")");
+		}
+
+		RangerPerfTracer perf = null;
+
+		if(RangerPerfTracer.isPerfTraceEnabled(PERF_POLICYENGINE_GET_ACLS_LOG)) {
+			perf = RangerPerfTracer.getPerfTracer(PERF_POLICYENGINE_GET_ACLS_LOG, "RangerPolicyEngine.getResourceACLs(requestHashCode=" + request.getResource().getAsString() + ")");
+		}
+
+		RangerResourceACLs          ret                      = new RangerResourceACLs();
+		Set<RangerTagForEval>       tags                     = RangerAccessRequestUtil.getRequestTagsFromContext(request.getContext());
+		List<PolicyEvaluatorForTag> tagPolicyEvaluators      = tagPolicyRepository == null ? null : tagPolicyRepository.getLikelyMatchPolicyEvaluators(tags, RangerPolicy.POLICY_TYPE_ACCESS, null);
+		List<RangerPolicyEvaluator> resourcePolicyEvaluators = policyRepository.getLikelyMatchPolicyEvaluators(request.getResource(), RangerPolicy.POLICY_TYPE_ACCESS);
+		List<RangerPolicyEvaluator> allEvaluators;
+		Map<Long, RangerPolicyResourceMatcher.MatchType> tagMatchTypeMap            = null;
+		Set<Long>                                        policyIdForTemporalTags    = null;
+
+		if (CollectionUtils.isNotEmpty(tagPolicyEvaluators)) {
+			allEvaluators   = new ArrayList<>();
+			tagMatchTypeMap = new HashMap<>();
+
+			for (PolicyEvaluatorForTag tagEvaluator : tagPolicyEvaluators) {
+				RangerPolicyEvaluator evaluator = tagEvaluator.getEvaluator();
+				RangerTagForEval      tag       = tagEvaluator.getTag();
+
+				allEvaluators.add(evaluator);
+				tagMatchTypeMap.put(evaluator.getId(), tag.getMatchType());
+
+				if (CollectionUtils.isNotEmpty(tag.getValidityPeriods())) {
+					if (policyIdForTemporalTags == null) {
+						policyIdForTemporalTags = new HashSet<>();
+					}
+
+					policyIdForTemporalTags.add(evaluator.getId());
+				}
+			}
+
+			allEvaluators.addAll(resourcePolicyEvaluators);
+			allEvaluators.sort(RangerPolicyEvaluator.EVAL_ORDER_COMPARATOR);
+		} else {
+			allEvaluators = resourcePolicyEvaluators;
+		}
+
+		if (CollectionUtils.isNotEmpty(allEvaluators)) {
+			Integer policyPriority = null;
+
+			for (RangerPolicyEvaluator evaluator : allEvaluators) {
+				if (policyPriority == null) {
+					policyPriority = evaluator.getPolicyPriority();
+				}
+
+				if (policyPriority != evaluator.getPolicyPriority()) {
+					ret.finalizeAcls();
+
+					policyPriority = evaluator.getPolicyPriority();
+				}
+
+				RangerPolicyResourceMatcher.MatchType matchType = tagMatchTypeMap != null ? tagMatchTypeMap.get(evaluator.getId()) : null;
+
+				if (matchType == null) {
+					matchType = evaluator.getPolicyResourceMatcher().getMatchType(request.getResource(), request.getContext());
+				}
+
+				final boolean isMatched;
+
+				if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
+					isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
+				} else {
+					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
+				}
+
+				if (!isMatched) {
+					continue;
+				}
+
+				PolicyACLSummary aclSummary = evaluator.getPolicyACLSummary();
+
+				if (aclSummary != null) {
+
+					boolean isConditional = (policyIdForTemporalTags != null && policyIdForTemporalTags.contains(evaluator.getId())) || evaluator.getValidityScheduleEvaluatorsCount() != 0;
+
+					Integer accessResult;
+					for (Map.Entry<String, Map<String, PolicyACLSummary.AccessResult>> userAccessInfo : aclSummary.getUsersAccessInfo().entrySet()) {
+						final String userName = userAccessInfo.getKey();
+
+						for (Map.Entry<String, PolicyACLSummary.AccessResult> accessInfo : userAccessInfo.getValue().entrySet()) {
+							if (isConditional) {
+								accessResult = ACCESS_CONDITIONAL;
+							} else {
+								accessResult = accessInfo.getValue().getResult();
+								if (accessResult.equals(RangerPolicyEvaluator.ACCESS_UNDETERMINED)) {
+									accessResult = RangerPolicyEvaluator.ACCESS_DENIED;
+								}
+							}
+							ret.setUserAccessInfo(userName, accessInfo.getKey(), accessResult);
+						}
+					}
+
+					for (Map.Entry<String, Map<String, PolicyACLSummary.AccessResult>> groupAccessInfo : aclSummary.getGroupsAccessInfo().entrySet()) {
+						final String groupName = groupAccessInfo.getKey();
+
+						for (Map.Entry<String, PolicyACLSummary.AccessResult> accessInfo : groupAccessInfo.getValue().entrySet()) {
+							if (isConditional) {
+								accessResult = ACCESS_CONDITIONAL;
+							} else {
+								accessResult = accessInfo.getValue().getResult();
+								if (accessResult.equals(RangerPolicyEvaluator.ACCESS_UNDETERMINED)) {
+									accessResult = RangerPolicyEvaluator.ACCESS_DENIED;
+								}
+							}
+							ret.setGroupAccessInfo(groupName, accessInfo.getKey(), accessResult);
+						}
+					}
+				}
+			}
+			ret.finalizeAcls();
+		}
+
+		RangerPerfTracer.logAlways(perf);
+
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerPolicyEngineImpl.getResourceACLs(request=" + request + ") : ret=" + ret);
+		}
+
+		return ret;
+	}
+
 	@Override
 	public boolean preCleanup() {
 
@@ -449,13 +595,13 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 	}
 
 	/*
-	* This API is used by ranger-admin
-	*/
+	 * This API is used by ranger-admin
+	 */
 
 	@Override
-	public boolean isAccessAllowed(Map<String, RangerPolicyResource> resources, String user, Set<String> userGroups, String accessType) {
+	public boolean isAccessAllowed(RangerPolicy policy, String user, Set<String> userGroups, String accessType) {
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerPolicyEngineImpl.isAccessAllowed(" + resources + ", " + user + ", " + userGroups + ", " + accessType + ")");
+			LOG.debug("==> RangerPolicyEngineImpl.isAccessAllowed(" + policy.getId() + ", " + user + ", " + userGroups + ", " + accessType + ")");
 		}
 
 		boolean ret = false;
@@ -467,7 +613,7 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		}
 
 		for (RangerPolicyEvaluator evaluator : policyRepository.getPolicyEvaluators()) {
-			ret = evaluator.isAccessAllowed(resources, user, userGroups, accessType);
+			ret = evaluator.isAccessAllowed(policy, user, userGroups, accessType);
 
 			if (ret) {
 				break;
@@ -477,12 +623,11 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		RangerPerfTracer.log(perf);
 
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerPolicyEngineImpl.isAccessAllowed(" + resources + ", " + user + ", " + userGroups + ", " + accessType + "): " + ret);
+			LOG.debug("<== RangerPolicyEngineImpl.isAccessAllowed(" + policy.getId() + ", " + user + ", " + userGroups + ", " + accessType + "): " + ret);
 		}
 
 		return ret;
 	}
-
 	/*
 	* This API is used by ranger-admin
 	*/
@@ -551,12 +696,27 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 			LOG.debug("==> RangerPolicyEngineImpl.getMatchingPolicies(" + resource + ")");
 		}
 
-		List<RangerPolicy> ret = new ArrayList<>();
-
 		RangerAccessRequestImpl request = new RangerAccessRequestImpl(resource, RangerPolicyEngine.ANY_ACCESS, null, null);
 
 		preProcess(request);
 
+		List<RangerPolicy> ret = getMatchingPolicies(request);
+
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerPolicyEngineImpl.getMatchingPolicies(" + resource + ") : " + ret.size());
+		}
+
+		return ret;
+	}
+
+	@Override
+	public List<RangerPolicy> getMatchingPolicies(RangerAccessRequest request) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerPolicyEngineImpl.getMatchingPolicies(" + request + ")");
+		}
+
+		List<RangerPolicy> ret = new ArrayList<>();
+
 		if (hasTagPolicies()) {
 			Set<RangerTagForEval> tags = RangerAccessRequestUtil.getRequestTagsFromContext(request.getContext());
 
@@ -568,7 +728,8 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 
 					for (RangerPolicyEvaluator evaluator : likelyEvaluators) {
 						RangerPolicyResourceMatcher matcher = evaluator.getPolicyResourceMatcher();
-						if (matcher != null && matcher.isMatch(tagResource, RangerPolicyResourceMatcher.MatchScope.ANY, null)) {
+						if (matcher != null &&
+								(request.isAccessTypeAny() ? matcher.isMatch(tagResource, RangerPolicyResourceMatcher.MatchScope.ANY, null) : matcher.isMatch(tagResource, null))) {
 							ret.add(evaluator.getPolicy());
 						}
 					}
@@ -578,11 +739,12 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		}
 
 		if (hasResourcePolicies()) {
-			List<RangerPolicyEvaluator> likelyEvaluators = policyRepository.getLikelyMatchPolicyEvaluators(resource);
+			List<RangerPolicyEvaluator> likelyEvaluators = policyRepository.getLikelyMatchPolicyEvaluators(request.getResource());
 
 			for (RangerPolicyEvaluator evaluator : likelyEvaluators) {
 				RangerPolicyResourceMatcher matcher = evaluator.getPolicyResourceMatcher();
-				if (matcher != null && matcher.isMatch(resource, RangerPolicyResourceMatcher.MatchScope.ANY, null)) {
+				if (matcher != null &&
+						(request.isAccessTypeAny() ? matcher.isMatch(request.getResource(), RangerPolicyResourceMatcher.MatchScope.ANY, null) : matcher.isMatch(request.getResource(), null))) {
 					ret.add(evaluator.getPolicy());
 				}
 			}
@@ -590,7 +752,7 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		}
 
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerPolicyEngineImpl.getMatchingPolicies(" + resource + ") : " + ret.size());
+			LOG.debug("<== RangerPolicyEngineImpl.getMatchingPolicies(" + request + ") : " + ret.size());
 		}
 		return ret;
 	}
@@ -644,6 +806,41 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		return ret;
 	}
 
+	/*
+	 * This API is used by test-code
+	 */
+
+	@Override
+	public boolean isAccessAllowed(Map<String, RangerPolicyResource> resources, String user, Set<String> userGroups, String accessType) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerPolicyEngineImpl.isAccessAllowed(" + resources + ", " + user + ", " + userGroups + ", " + accessType + ")");
+		}
+
+		boolean ret = false;
+
+		RangerPerfTracer perf = null;
+
+		if(RangerPerfTracer.isPerfTraceEnabled(PERF_POLICYENGINE_REQUEST_LOG)) {
+			perf = RangerPerfTracer.getPerfTracer(PERF_POLICYENGINE_REQUEST_LOG, "RangerPolicyEngine.isAccessAllowed(user=" + user + "," + userGroups + ",accessType=" + accessType + ")");
+		}
+
+		for (RangerPolicyEvaluator evaluator : policyRepository.getPolicyEvaluators()) {
+			ret = evaluator.isAccessAllowed(resources, user, userGroups, accessType);
+
+			if (ret) {
+				break;
+			}
+		}
+
+		RangerPerfTracer.log(perf);
+
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerPolicyEngineImpl.isAccessAllowed(" + resources + ", " + user + ", " + userGroups + ", " + accessType + "): " + ret);
+		}
+
+		return ret;
+	}
+
 	/*
 	* This API is used only by test-code
 	*/
@@ -656,7 +853,8 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 
 		List<RangerPolicy> ret = new ArrayList<>();
 
-		// TODO: run through evaluator in tagPolicyRepository as well
+
+        // TODO: run through evaluator in tagPolicyRepository as well
 		for (RangerPolicyEvaluator evaluator : policyRepository.getPolicyEvaluators()) {
 			RangerPolicy policy = evaluator.getPolicy();
 
@@ -680,42 +878,56 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 		}
 
 		RangerAccessResult ret = createAccessResult(request, policyType);
+		Date accessTime = request.getAccessTime();
 
-		if (ret != null && request != null) {
+        if (ret != null && request != null) {
 
-			if (hasTagPolicies()) {
+			evaluateTagPolicies(request, policyType, ret);
 
-				evaluateTagPolicies(request, policyType, ret);
-
-				if (LOG.isDebugEnabled()) {
-					if (ret.getIsAccessDetermined() && ret.getIsAuditedDetermined()) {
-						LOG.debug("RangerPolicyEngineImpl.evaluatePoliciesNoAudit() - access and audit determined by tag policy. request=" + request + ", result=" + ret);
+			if (LOG.isDebugEnabled()) {
+				if (ret.getIsAccessDetermined() && ret.getIsAuditedDetermined()) {
+					if (!ret.getIsAllowed()) {
+						LOG.debug("RangerPolicyEngineImpl.evaluatePoliciesNoAudit() - audit determined and access denied by a tag policy. Higher priority resource policies will be evaluated to check for allow, request=" + request + ", result=" + ret);
+					} else {
+						LOG.debug("RangerPolicyEngineImpl.evaluatePoliciesNoAudit() - audit determined and access allowed by a tag policy. Same or higher priority resource policies will be evaluated to check for deny, request=" + request + ", result=" + ret);
 					}
 				}
 			}
 
 			boolean isAllowedByTags          = ret.getIsAccessDetermined() && ret.getIsAllowed();
 			boolean isDeniedByTags           = ret.getIsAccessDetermined() && !ret.getIsAllowed();
-			boolean evaluateResourcePolicies = hasResourcePolicies() && (!isDeniedByTags || !ret.getIsAuditedDetermined());
+			boolean evaluateResourcePolicies = hasResourcePolicies();
 
 			if (evaluateResourcePolicies) {
-
 				boolean findAuditByResource = !ret.getIsAuditedDetermined();
 				boolean foundInCache        = findAuditByResource && policyRepository.setAuditEnabledFromCache(request, ret);
 
-				if(isAllowedByTags) {
-					ret.setIsAccessDetermined(false); // discard allowed result by tag-policies, to evaluate resource policies for possible deny
-				}
+				ret.setIsAccessDetermined(false); // discard result by tag-policies, to evaluate resource policies for possible override
 
 				List<RangerPolicyEvaluator> evaluators = policyRepository.getLikelyMatchPolicyEvaluators(request.getResource(), policyType);
 
 				for (RangerPolicyEvaluator evaluator : evaluators) {
+					if (!evaluator.isApplicable(accessTime)) {
+						continue;
+					}
+
+					if (isDeniedByTags) {
+						if (ret.getPolicyPriority() >= evaluator.getPolicyPriority()) {
+							ret.setIsAccessDetermined(true);
+						}
+					} else if (isAllowedByTags) {
+						if (ret.getPolicyPriority() > evaluator.getPolicyPriority()) {
+							ret.setIsAccessDetermined(true);
+						}
+					}
 
 					ret.incrementEvaluatedPoliciesCount();
 					evaluator.evaluate(request, ret);
 
-					if (ret.getIsAllowed() && !evaluator.hasDeny()) { // all policies having deny have been evaluated
-						ret.setIsAccessDetermined(true);
+					if (ret.getIsAllowed()) {
+						if (!evaluator.hasDeny()) { // No more deny policies left
+							ret.setIsAccessDetermined(true);
+						}
 					}
 
 					if (ret.getIsAuditedDetermined() && ret.getIsAccessDetermined()) {
@@ -724,6 +936,14 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 
 				}
 
+				if (!ret.getIsAccessDetermined()) {
+					if (isDeniedByTags) {
+						ret.setIsAllowed(false);
+					} else if (isAllowedByTags) {
+						ret.setIsAllowed(true);
+					}
+				}
+
 				if(ret.getIsAllowed()) {
 					ret.setIsAccessDetermined(true);
 				}
@@ -746,15 +966,16 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 			LOG.debug("==> RangerPolicyEngineImpl.evaluateTagPolicies(" + request + ", policyType =" + policyType + ", " + result + ")");
 		}
 
+		Date accessTime = request.getAccessTime();
+
 		Set<RangerTagForEval> tags = RangerAccessRequestUtil.getRequestTagsFromContext(request.getContext());
 
-		List<PolicyEvaluatorForTag> policyEvaluators = tagPolicyRepository.getLikelyMatchPolicyEvaluators(tags, policyType);
+		List<PolicyEvaluatorForTag> policyEvaluators = tagPolicyRepository == null ? null : tagPolicyRepository.getLikelyMatchPolicyEvaluators(tags, policyType, accessTime);
 
 		if (CollectionUtils.isNotEmpty(policyEvaluators)) {
-
 			for (PolicyEvaluatorForTag policyEvaluator : policyEvaluators) {
-
 				RangerPolicyEvaluator evaluator = policyEvaluator.getEvaluator();
+
 				RangerTagForEval tag = policyEvaluator.getTag();
 
 				RangerAccessRequest tagEvalRequest = new RangerTagAccessRequest(tag, tagPolicyRepository.getServiceDef(), request);
@@ -771,8 +992,10 @@ public class RangerPolicyEngineImpl implements RangerPolicyEngine {
 
 				evaluator.evaluate(tagEvalRequest, tagEvalResult);
 
-				if (tagEvalResult.getIsAllowed() && !evaluator.hasDeny()) { // all policies having deny have been evaluated
-					tagEvalResult.setIsAccessDetermined(true);
+				if (tagEvalResult.getIsAllowed()) {
+					if (!evaluator.hasDeny()) { // No Deny policies left now
+						tagEvalResult.setIsAccessDetermined(true);
+					}
 				}
 
 				if (tagEvalResult.getIsAudited()) {
