@@ -73,6 +73,11 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 		return policy;
 	}
 
+	@Override
+	public int getPolicyPriority() {
+		return policy != null && policy.getPolicyPriority() != null ? policy.getPolicyPriority() : RangerPolicy.POLICY_PRIORITY_NORMAL;
+	}
+
 	@Override
 	public RangerServiceDef getServiceDef() {
 		return serviceDef;
@@ -129,6 +134,9 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 		this.usageCountMutable = true;
 	}
 
+	@Override
+	public PolicyACLSummary getPolicyACLSummary() { return null; }
+
 	@Override
 	public String toString( ) {
 		StringBuilder sb = new StringBuilder();
