@@ -25,13 +25,18 @@ import java.util.Hashtable;
 import java.util.Map;
 import java.util.Timer;
 import java.util.TimerTask;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.admin.client.RangerAdminClient;
 import org.apache.ranger.admin.client.RangerAdminRESTClient;
+import org.apache.ranger.audit.provider.AuditHandler;
+import org.apache.ranger.audit.provider.AuditProviderFactory;
+import org.apache.ranger.audit.provider.StandAloneAuditProviderFactory;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
+import org.apache.ranger.authorization.utils.StringUtil;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
@@ -54,6 +59,8 @@ public class RangerBasePlugin {
 
 	public static final char RANGER_TRUSTED_PROXY_IPADDRESSES_SEPARATOR_CHAR = ',';
 
+	private static Map<String, RangerBasePlugin> servicePluginMap = new ConcurrentHashMap<>();
+
 	private String                    serviceType;
 	private String                    appId;
 	private String                    serviceName;
@@ -61,14 +68,61 @@ public class RangerBasePlugin {
 	private PolicyRefresher           refresher;
 	private RangerPolicyEngine        policyEngine;
 	private RangerPolicyEngineOptions policyEngineOptions = new RangerPolicyEngineOptions();
+	private RangerAuthContext         currentAuthContext;
+	private RangerAuthContext         readOnlyAuthContext;
 	private RangerAccessResultProcessor resultProcessor;
 	private boolean                   useForwardedIPAddress;
 	private String[]                  trustedProxyAddresses;
 	private Timer                     policyEngineRefreshTimer;
+	private RangerAuthContextListener authContextListener;
+	private AuditProviderFactory      auditProviderFactory;
+
 
 	Map<String, LogHistory> logHistoryList = new Hashtable<String, RangerBasePlugin.LogHistory>();
 	int logInterval = 30000; // 30 seconds
 
+	public static Map<String, RangerBasePlugin> getServicePluginMap() {
+		return servicePluginMap;
+	}
+
+	public static AuditHandler getAuditProvider(String serviceName) {
+		AuditHandler ret = null;
+
+		boolean useStandaloneAuditProvider = false;
+
+		if (StringUtils.isNotEmpty(serviceName)) {
+			RangerBasePlugin plugin = RangerBasePlugin.getServicePluginMap().get(serviceName);
+			if (plugin != null) {
+				if (plugin.getAuditProviderFactory() != null) {
+					ret = plugin.getAuditProviderFactory().getAuditProvider();
+				} else {
+					LOG.error("NULL AuditProviderFactory for serviceName:[" + serviceName + "]");
+				}
+			} else {
+				useStandaloneAuditProvider = true;
+			}
+		} else {
+			useStandaloneAuditProvider = true;
+		}
+
+		if (useStandaloneAuditProvider) {
+			StandAloneAuditProviderFactory factory = StandAloneAuditProviderFactory.getInstance();
+			if (factory.isInitDone()) {
+				ret = factory.getAuditProvider();
+			} else {
+				RangerConfiguration conf = RangerConfiguration.getInstance();
+				String auditCfg = "ranger-standalone-audit.xml";
+				if (conf.addResourceIfReadable(auditCfg)) {
+					factory.init(conf.getProperties(), "StandAlone");
+					ret = factory.getAuditProvider();
+				} else {
+					LOG.error("StandAlone audit handler configuration not readable:[" + auditCfg + "]");
+				}
+			}
+		}
+
+		return ret;
+	}
 
 	public RangerBasePlugin(String serviceType, String appId) {
 		this.serviceType = serviceType;
@@ -83,6 +137,12 @@ public class RangerBasePlugin {
 		return clusterName;
 	}
 
+	public RangerAuthContext createRangerAuthContext() {
+		return new RangerAuthContext(readOnlyAuthContext);
+	}
+
+	public RangerAuthContext getCurrentRangerAuthContext() { return currentAuthContext; }
+
 	public void setClusterName(String clusterName) {
 		this.clusterName = clusterName;
 	}
@@ -107,12 +167,13 @@ public class RangerBasePlugin {
 		return serviceName;
 	}
 
+	public AuditProviderFactory getAuditProviderFactory() { return auditProviderFactory; }
+
 	public void init() {
 		cleanup();
 
 		RangerConfiguration configuration = RangerConfiguration.getInstance();
 		configuration.addResourcesForServiceType(serviceType);
-		configuration.initAudit(appId);
 
 		String propertyPrefix    = "ranger.plugin." + serviceType;
 		long   pollingIntervalMs = configuration.getLong(propertyPrefix + ".policy.pollIntervalMs", 30 * 1000);
@@ -139,10 +200,21 @@ public class RangerBasePlugin {
 			LOG.warn("Ranger plugin will trust RemoteIPAddress and treat first X-Forwarded-Address in the access-request as the clientIPAddress");
 		}
 
+		if (configuration.getProperties() != null) {
+			auditProviderFactory = new AuditProviderFactory();
+			auditProviderFactory.init(configuration.getProperties(), appId);
+		} else {
+			LOG.error("Audit subsystem is not initialized correctly. Please check audit configuration. ");
+			LOG.error("No authorization audits will be generated. ");
+			auditProviderFactory = null;
+		}
+
 		policyEngineOptions.configureForPlugin(configuration, propertyPrefix);
 
 		LOG.info(policyEngineOptions);
 
+		servicePluginMap.put(serviceName, this);
+
 		RangerAdminClient admin = createAdminClient(serviceName, appId, propertyPrefix);
 
 		refresher = new PolicyRefresher(this, serviceType, appId, serviceName, admin, pollingIntervalMs, cacheDir);
@@ -186,13 +258,17 @@ public class RangerBasePlugin {
 			}
 			if (policies == null) {
 				this.policyEngine = null;
+				readOnlyAuthContext = null;
 			} else {
+				currentAuthContext = new RangerAuthContext();
 				RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(appId, policies, policyEngineOptions);
 				policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
 				policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
-
 				this.policyEngine = policyEngine;
+				currentAuthContext.setPolicyEngine(this.policyEngine);
+				readOnlyAuthContext = new RangerAuthContext(currentAuthContext);
 			}
+			contextChanged();
 
 			if (oldPolicyEngine != null && !oldPolicyEngine.preCleanup()) {
 				LOG.error("preCleanup() failed on the previous policy engine instance !!");
@@ -202,6 +278,14 @@ public class RangerBasePlugin {
 		}
 	}
 
+	public void contextChanged() {
+		RangerAuthContextListener authContextListener = this.authContextListener;
+
+		if (authContextListener != null) {
+			authContextListener.contextChanged();
+		}
+	}
+
 	public void cleanup() {
 
 		PolicyRefresher refresher = this.refresher;
@@ -210,6 +294,8 @@ public class RangerBasePlugin {
 
 		Timer policyEngineRefreshTimer = this.policyEngineRefreshTimer;
 
+		String serviceName = this.serviceName;
+
 		this.serviceName  = null;
 		this.policyEngine = null;
 		this.refresher    = null;
@@ -227,6 +313,9 @@ public class RangerBasePlugin {
 			policyEngine.cleanup();
 		}
 
+		if (serviceName != null) {
+			servicePluginMap.remove(serviceName);
+		}
 	}
 
 	public void setResultProcessor(RangerAccessResultProcessor resultProcessor) {
@@ -357,6 +446,13 @@ public class RangerBasePlugin {
 		}
 	}
 
+	public void registerAuthContextEventListener(RangerAuthContextListener authContextListener) {
+		this.authContextListener = authContextListener;
+	}
+	public void unregisterAuthContextEventListener(RangerAuthContextListener authContextListener) {
+		this.authContextListener = null;
+	}
+
 	public static RangerAdminClient createAdminClient(String rangerServiceName, String applicationId, String propertyPrefix) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerBasePlugin.createAdminClient(" + rangerServiceName + ", " + applicationId + ", " + propertyPrefix + ")");
@@ -401,7 +497,7 @@ public class RangerBasePlugin {
 		if(request != null && resultProcessor != null) {
 			RangerAccessRequestImpl accessRequest = new RangerAccessRequestImpl();
 	
-			accessRequest.setResource(new RangerAccessResourceImpl(request.getResource()));
+			accessRequest.setResource(new RangerAccessResourceImpl(StringUtil.toStringObjectMap(request.getResource())));
 			accessRequest.setUser(request.getGrantor());
 			accessRequest.setAccessType(RangerPolicyEngine.ADMIN_ACCESS);
 			accessRequest.setAction(action);
