@@ -23,6 +23,7 @@ import java.security.PrivilegedExceptionAction;
 
 import org.apache.commons.io.IOUtils;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.fs.ContentSummary;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
@@ -45,6 +46,10 @@ import org.junit.Assert;
  * A custom RangerAdminClient is plugged into Ranger in turn, which loads security policies from a local file. These policies were
  * generated in the Ranger Admin UI for a service called "HDFSTest". It contains three policies, each of which grants read, write and
  * execute permissions in turn to "/tmp/tmpdir", "/tmp/tmpdir2" and "/tmp/tmpdir3" to a user called "bob" and to a group called "IT".
+ *
+ * In addition we have a TAG based policy, which grants "read" access to "bob" and the "IT" group to "/tmp/tmpdir6" (which is associated
+ * with the tag called "TmpdirTag". A "hdfs_path" entity was created in Apache Atlas + then associated with the "TmpdirTag". This was
+ * then imported into Ranger using the TagSyncService. The policies were then downloaded locally and saved for testing off-line.
  */
 public class HDFSRangerTest {
 
@@ -230,6 +235,116 @@ public class HDFSRangerTest {
         });
 
     }
+
+    @org.junit.Test
+    public void readTestUsingTagPolicy() throws Exception {
+        FileSystem fileSystem = hdfsCluster.getFileSystem();
+
+        // Write a file - the AccessControlEnforcer won't be invoked as we are the "superuser"
+        final Path file = new Path("/tmp/tmpdir6/data-file2");
+        FSDataOutputStream out = fileSystem.create(file);
+        for (int i = 0; i < 1024; ++i) {
+            out.write(("data" + i + "\n").getBytes("UTF-8"));
+            out.flush();
+        }
+        out.close();
+
+        // Change permissions to read-only
+        fileSystem.setPermission(file, new FsPermission(FsAction.READ, FsAction.NONE, FsAction.NONE));
+
+        // Now try to read the file as "bob" - this should be allowed (by the policy - user)
+        UserGroupInformation ugi = UserGroupInformation.createUserForTesting("bob", new String[] {});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+
+            public Void run() throws Exception {
+                Configuration conf = new Configuration();
+                conf.set("fs.defaultFS", defaultFs);
+
+                FileSystem fs = FileSystem.get(conf);
+
+                // Read the file
+                FSDataInputStream in = fs.open(file);
+                ByteArrayOutputStream output = new ByteArrayOutputStream();
+                IOUtils.copy(in, output);
+                String content = new String(output.toByteArray());
+                Assert.assertTrue(content.startsWith("data0"));
+
+                fs.close();
+                return null;
+            }
+        });
+
+        // Now try to read the file as "alice" - this should be allowed (by the policy - group)
+        ugi = UserGroupInformation.createUserForTesting("alice", new String[] {"IT"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+
+            public Void run() throws Exception {
+                Configuration conf = new Configuration();
+                conf.set("fs.defaultFS", defaultFs);
+
+                FileSystem fs = FileSystem.get(conf);
+
+                // Read the file
+                FSDataInputStream in = fs.open(file);
+                ByteArrayOutputStream output = new ByteArrayOutputStream();
+                IOUtils.copy(in, output);
+                String content = new String(output.toByteArray());
+                Assert.assertTrue(content.startsWith("data0"));
+
+                fs.close();
+                return null;
+            }
+        });
+
+        // Now try to read the file as unknown user "eve" - this should not be allowed
+        ugi = UserGroupInformation.createUserForTesting("eve", new String[] {});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+
+            public Void run() throws Exception {
+                Configuration conf = new Configuration();
+                conf.set("fs.defaultFS", defaultFs);
+
+                FileSystem fs = FileSystem.get(conf);
+
+                // Read the file
+                try {
+                    fs.open(file);
+                    Assert.fail("Failure expected on an incorrect permission");
+                } catch (RemoteException ex) {
+                    // expected
+                    Assert.assertTrue(RangerAccessControlException.class.getName().equals(ex.getClassName()));
+                }
+
+                fs.close();
+                return null;
+            }
+        });
+
+        // Now try to read the file as known user "dave" - this should not be allowed, as he doesn't have the correct permissions
+        ugi = UserGroupInformation.createUserForTesting("dave", new String[] {});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+
+            public Void run() throws Exception {
+                Configuration conf = new Configuration();
+                conf.set("fs.defaultFS", defaultFs);
+
+                FileSystem fs = FileSystem.get(conf);
+
+                // Read the file
+                try {
+                    fs.open(file);
+                    Assert.fail("Failure expected on an incorrect permission");
+                } catch (RemoteException ex) {
+                    // expected
+                    Assert.assertTrue(RangerAccessControlException.class.getName().equals(ex.getClassName()));
+                }
+
+                fs.close();
+                return null;
+            }
+        });
+    }
+
     @org.junit.Test
     public void HDFSFileNameTokenReadTest() throws Exception {
         HDFSReadTest("/tmp/tmpdir4/data-file");
@@ -243,6 +358,11 @@ public class HDFSRangerTest {
         HDFSReadFailTest("/tmp/tmpdir5/t/data-file.txt");
     }
 
+    @org.junit.Test
+    public void HDFSContentSummaryTest() throws Exception {
+        HDFSGetContentSummary("/tmp/get-content-summary");
+    }
+
     void HDFSReadTest(String fileName) throws Exception {
         FileSystem fileSystem = hdfsCluster.getFileSystem();
 
@@ -413,4 +533,53 @@ public class HDFSRangerTest {
             }
         });
     }
+
+    void HDFSGetContentSummary(final String dirName) throws Exception {
+
+        String subdirName = dirName + "/tmpdir";
+
+        createFile(subdirName, 1);
+        createFile(subdirName, 2);
+
+        UserGroupInformation ugi = UserGroupInformation.createUserForTesting("bob", new String[] {});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+
+            public Void run() throws Exception {
+                Configuration conf = new Configuration();
+                conf.set("fs.defaultFS", defaultFs);
+
+                FileSystem fs = FileSystem.get(conf);
+
+                try {
+                    // GetContentSummary on the directory dirName
+                    ContentSummary contentSummary = fs.getContentSummary(new Path(dirName));
+
+                    long directoryCount = contentSummary.getDirectoryCount();
+                    Assert.assertTrue("Found unexpected number of directories; expected-count=3, actual-count=" + directoryCount, directoryCount == 3);
+                } catch (Exception e) {
+                    Assert.fail("Failed to getContentSummary, exception=" + e);
+                }
+                fs.close();
+                return null;
+            }
+        });
+    }
+
+    void createFile(String baseDir, Integer index) throws Exception {
+        FileSystem fileSystem = hdfsCluster.getFileSystem();
+
+        // Write a file - the AccessControlEnforcer won't be invoked as we are the "superuser"
+        String dirName = baseDir + (index != null ? String.valueOf(index) : "");
+        String fileName = dirName + "/dummy-data";
+        final Path file = new Path(fileName);
+        FSDataOutputStream out = fileSystem.create(file);
+        for (int i = 0; i < 1024; ++i) {
+            out.write(("data" + i + "\n").getBytes("UTF-8"));
+            out.flush();
+        }
+        out.close();
+
+        // Change permissions to read-only
+        fileSystem.setPermission(file, new FsPermission(FsAction.READ, FsAction.NONE, FsAction.NONE));
+    }
 }
