@@ -38,7 +38,6 @@ function getInstallProperty() {
 # Base env variable for Ranger related files/directories
 #
 PROJ_NAME=ranger
-BASE_CONF_DIR=/etc/${PROJ_NAME}
 
 #
 # The script should be run by "root" user
@@ -496,7 +495,7 @@ then
 	#
 	# Encrypt the password and keep it secure in Credential Provider API
 	#
-	
+
 	CredFile=${CREDENTIAL_PROVIDER_FILE}
 
 	if ! [ `echo ${CredFile} | grep '^/.*'` ]
@@ -504,9 +503,9 @@ then
   	echo "ERROR:Please enter the Credential File Store with proper file path"
   	exit 1
 	fi
-	
+
 	pardir=`dirname ${CredFile}`
-	
+
 	if [ ! -d "${pardir}" ]
 	then
 		mkdir -p "${pardir}" 
@@ -519,45 +518,27 @@ then
 		chmod a+rx "${pardir}"
 	fi
 
-	#
-	# Generate Credential Provider file and Credential for Audit DB access.
-	#
-	
-	
-	auditCredAlias="auditDBCred"
-	
-	auditdbCred=$(getInstallProperty 'XAAUDIT.DB.PASSWORD')
-	
-	if [ "${auditdbCred}" != "" ]; then
-		create_jceks "${auditCredAlias}"  "${auditdbCred}"  "${CredFile}"
-	fi
-	
-	
 	#
 	# Generate Credential Provider file and Credential for SSL KEYSTORE AND TRUSTSTORE
 	#
-	
-	
 	sslkeystoreAlias="sslKeyStore"
-	
+
 	sslkeystoreCred=$(getInstallProperty 'SSL_KEYSTORE_PASSWORD')
-	
+
 	create_jceks "${sslkeystoreAlias}" "${sslkeystoreCred}" "${CredFile}"
-	
-	
+
 	ssltruststoreAlias="sslTrustStore"
-	
+
 	ssltruststoreCred=$(getInstallProperty 'SSL_TRUSTSTORE_PASSWORD')
-	
+
 	create_jceks "${ssltruststoreAlias}" "${ssltruststoreCred}" "${CredFile}"
-	
+
 	chown ${CFG_OWNER_INF} ${CredFile}
 	#
 	# To allow all users in the server (where Hive CLI and HBase CLI is used),
 	# user needs to have read access for the credential file.
 	#
 	chmod a+r ${CredFile} 
-	
 fi
 
 #
