@@ -78,9 +78,11 @@ public class ServiceMgr {
 	@Autowired
 	TimedExecutor timedExecutor;
 
+        @Autowired
+        RangerBizUtil rangerBizUtil;
+
 	public List<String> lookupResource(String serviceName, ResourceLookupContext context, ServiceStore svcStore) throws Exception {
 		List<String> 	  ret = null;
-		
 		RangerService service = svcDBStore.getServiceByName(serviceName);
 		
 		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE);
@@ -135,7 +137,6 @@ public class ServiceMgr {
 	
 	public VXResponse validateConfig(RangerService service, ServiceStore svcStore) throws Exception {
 		VXResponse        ret = new VXResponse();
-		
 		String authType = PropertiesUtil.getProperty(AUTHENTICATION_TYPE);
 		String lookupPrincipal = SecureClientLogin.getPrincipal(PropertiesUtil.getProperty(LOOKUP_PRINCIPAL), PropertiesUtil.getProperty(HOST_NAME));
 		String lookupKeytab = PropertiesUtil.getProperty(LOOKUP_KEYTAB);
