@@ -132,12 +132,12 @@ public class XUserMgr extends XUserMgrBase {
 	@Autowired
 	GUIDUtil guidUtil;
 
-    @Autowired
-    UserMgr userManager;
-
 	@Autowired
 	XUgsyncAuditInfoService xUgsyncAuditInfoService;
 
+	@Autowired
+	XGroupUserService xGroupUserService;
+
 	static final Logger logger = Logger.getLogger(XUserMgr.class);
 
 
@@ -173,7 +173,7 @@ public class XUserMgr extends XUserMgrBase {
 		}
 
 		if (vXUser.getDescription() == null) {
-			setUserDesc(vXUser);
+			vXUser.setDescription(vXUser.getName());
 		}
 
 		String actualPassword = vXUser.getPassword();
@@ -325,7 +325,7 @@ public class XUserMgr extends XUserMgrBase {
 		return null;
 	}
 
-	private VXGroupUser createXGroupUser(Long userId, Long groupId) {
+	protected VXGroupUser createXGroupUser(Long userId, Long groupId) {
 		VXGroupUser vXGroupUser = new VXGroupUser();
 		vXGroupUser.setParentGroupId(groupId);
 		vXGroupUser.setUserId(userId);
@@ -347,11 +347,15 @@ public class XUserMgr extends XUserMgrBase {
                 xaBizUtil.blockAuditorRoleUser();
 		VXPortalUser oldUserProfile = userMgr.getUserProfileByLoginId(vXUser
 				.getName());
+		if (oldUserProfile == null) {
+			throw restErrorUtil.createRESTException(
+					"user " + vXUser.getName() + " does not exist.",
+					MessageEnums.INVALID_INPUT_DATA);
+		}
 		VXPortalUser vXPortalUser = new VXPortalUser();
 		if (oldUserProfile != null && oldUserProfile.getId() != null) {
 			vXPortalUser.setId(oldUserProfile.getId());
 		}
-		// TODO : There is a possibility that old user may not exist.
 
 		vXPortalUser.setFirstName(vXUser.getFirstName());
 		if("null".equalsIgnoreCase(vXPortalUser.getFirstName())){
@@ -538,8 +542,7 @@ public class XUserMgr extends XUserMgrBase {
         List<String> existingRole = daoManager.getXXPortalUserRole()
                 .findXPortalUserRolebyXPortalUserId(xxPortalUser.getId());
         if (xxPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
-            vXPortalUser = userManager.updateRoleForExternalUsers(reqRoleList,
-                    existingRole, vXPortalUser);
+            vXPortalUser = userMgr.updateRoleForExternalUsers(reqRoleList, existingRole, vXPortalUser);
         }
         vXUser = xUserService.createXUserWithOutLogin(vXUser);
         vxUGInfo.setXuserInfo(vXUser);
@@ -603,10 +606,10 @@ public class XUserMgr extends XUserMgrBase {
                 List<String> existingRole = daoManager.getXXPortalUserRole()
                         .findXPortalUserRolebyXPortalUserId(
                                 xxPortalUser.getId());
-                VXPortalUser vxPortalUser = userManager
+                VXPortalUser vxPortalUser = userMgr
                         .mapXXPortalUserToVXPortalUserForDefaultAccount(xxPortalUser);
                 if (xxPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
-                    vxPortalUser = userManager.updateRoleForExternalUsers(
+                    vxPortalUser = userMgr.updateRoleForExternalUsers(
                             reqRoleList, existingRole, vxPortalUser);
                     assignPermissionToUser(vxPortalUser, true);
                 }
@@ -701,11 +704,38 @@ public class XUserMgr extends XUserMgrBase {
 	public VXUser getXUser(Long id) {
 		VXUser vXUser=null;
 		vXUser=xUserService.readResourceWithOutLogin(id);
+		if(vXUser != null){
+			if(!hasAccessToGetUserInfo(vXUser)){
+				logger.info("Logged-In user is not allowed to access requested user data.");
+				throw restErrorUtil.create403RESTException("Logged-In user is not allowed to access requested user data.");
+			}
+		}
+		
 		if(vXUser!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
 			vXUser=getMaskedVXUser(vXUser);
 		}
 		return vXUser;
 	}
+	
+	private boolean hasAccessToGetUserInfo(VXUser requestedVXUser) {
+		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
+		if (userSession != null && userSession.getLoginId() != null) {
+			VXUser loggedInVXUser = xUserService.getXUserByUserName(userSession
+					.getLoginId());
+			if (loggedInVXUser != null) {
+				if (loggedInVXUser.getUserRoleList().size() == 1
+						&& loggedInVXUser.getUserRoleList().contains(
+								RangerConstants.ROLE_USER)) {
+					
+					return requestedVXUser.getId().equals(loggedInVXUser.getId()) ? true : false;
+									
+				}else{
+					return true;
+				}
+			}
+		}
+		return false;
+	}
 
 	public VXGroupUser getXGroupUser(Long id) {
 		return xGroupUserService.readResourceWithOutLogin(id);
@@ -714,6 +744,28 @@ public class XUserMgr extends XUserMgrBase {
 
 	public VXGroup getXGroup(Long id) {
 		VXGroup vXGroup=null;
+		
+		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
+		if (userSession != null && userSession.getLoginId() != null) {
+			VXUser loggedInVXUser = xUserService.getXUserByUserName(userSession
+					.getLoginId());
+			if (loggedInVXUser != null) {
+				if (loggedInVXUser.getUserRoleList().size() == 1
+						&& loggedInVXUser.getUserRoleList().contains(
+								RangerConstants.ROLE_USER)) {
+
+					List<Long> listGroupId = daoManager.getXXGroupUser()
+							.findGroupIdListByUserId(loggedInVXUser.getId());
+
+					if (!listGroupId.contains(id)) {
+						logger.info("Logged-In user is not allowed to access requested user data.");
+						throw restErrorUtil
+								.create403RESTException("Logged-In user is not allowed to access requested group data.");
+					}
+
+				}
+			}
+		}
 		vXGroup=xGroupService.readResourceWithOutLogin(id);
 		if(vXGroup!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
 			vXGroup=getMaskedVXGroup(vXGroup);
@@ -851,16 +903,16 @@ public class XUserMgr extends XUserMgrBase {
 		return vXUserList;
 	}
 
-	// FIXME Hack : Unnecessary, to be removed after discussion.
-	private void setUserDesc(VXUser vXUser) {
-		vXUser.setDescription(vXUser.getName());
-	}
-
 	@Override
 	public VXGroup updateXGroup(VXGroup vXGroup) {
 		checkAdminAccess();
                 xaBizUtil.blockAuditorRoleUser();
 		XXGroup xGroup = daoManager.getXXGroup().getById(vXGroup.getId());
+		if (vXGroup != null && xGroup != null && !vXGroup.getName().equals(xGroup.getName())) {
+			throw restErrorUtil.createRESTException(
+					"group name updates are not allowed.",
+					MessageEnums.INVALID_INPUT_DATA);
+		}
 		List<XXTrxLog> trxLogList = xGroupService.getTransactionLog(vXGroup,
 				xGroup, "update");
 		xaBizUtil.createTrxLog(trxLogList);
@@ -872,7 +924,7 @@ public class XUserMgr extends XUserMgrBase {
 		return vXGroup;
 	}
 
-	private void updateXgroupUserForGroupUpdate(VXGroup vXGroup) {
+	protected void updateXgroupUserForGroupUpdate(VXGroup vXGroup) {
 		List<XXGroupUser> grpUsers = daoManager.getXXGroupUser().findByGroupId(vXGroup.getId());
 		if(CollectionUtils.isNotEmpty(grpUsers)){
 			for (XXGroupUser grpUser : grpUsers) {
@@ -1264,10 +1316,8 @@ public class XUserMgr extends XUserMgrBase {
 	}
 
 	public VXPermMapList searchXPermMaps(SearchCriteria searchCriteria) {
-
-		VXPermMapList returnList;
+		VXPermMapList returnList = null;
 		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
-		// If user is system admin
 		if (currentUserSession != null && currentUserSession.isUserAdmin()) {
 			returnList = super.searchXPermMaps(searchCriteria);
 		} else {
@@ -1310,13 +1360,12 @@ public class XUserMgr extends XUserMgrBase {
 
 	public VXAuditMapList searchXAuditMaps(SearchCriteria searchCriteria) {
 
-		VXAuditMapList returnList;
+		VXAuditMapList returnList=new VXAuditMapList();
 		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
 		// If user is system admin
 		if (currentUserSession != null && currentUserSession.isUserAdmin()) {
 			returnList = super.searchXAuditMaps(searchCriteria);
 		} else {
-			returnList = new VXAuditMapList();
 			int startIndex = searchCriteria.getStartIndex();
 			int pageSize = searchCriteria.getMaxRows();
 			searchCriteria.setStartIndex(0);
@@ -1573,6 +1622,7 @@ public class XUserMgr extends XUserMgrBase {
 		VXUser vXUserExactMatch = null;
 		try{
 			VXUserList vXUserListSort = new VXUserList();
+			
 			if(searchCriteria.getParamList() != null && searchCriteria.getParamList().get("name") != null){
 				searchCriteria.setSortBy("name");
 				vXUserListSort = xUserService.searchXUsers(searchCriteria);
@@ -1605,8 +1655,8 @@ public class XUserMgr extends XUserMgrBase {
 							}
 							break;
 						case "emailaddress":
-							String email = vXUserExactMatch.getEmailAddress();
-							if(email != null && !email.equals(entry.getValue())){
+							String email = (String)entry.getValue();
+							if(email != null && !email.equals(vXUserExactMatch.getEmailAddress())){
 								vXUserExactMatchwithSearchCriteria = -1;
 							}
 							break;
@@ -1756,6 +1806,34 @@ public class XUserMgr extends XUserMgrBase {
 			searchCriteria.setSortBy("id");
 			vXGroupList=xGroupService.searchXGroups(searchCriteria);
 		}
+		
+		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
+		if (userSession != null && userSession.getLoginId() != null) {
+			VXUser loggedInVXUser = xUserService.getXUserByUserName(userSession
+					.getLoginId());
+			if (loggedInVXUser != null) {
+				if (loggedInVXUser.getUserRoleList().size() == 1
+						&& loggedInVXUser.getUserRoleList().contains(
+								RangerConstants.ROLE_USER)) {
+
+					List<VXGroup> updatedList = new ArrayList<VXGroup>();
+
+					List<Long> listGroupId = daoManager.getXXGroupUser()
+							.findGroupIdListByUserId(loggedInVXUser.getId());
+
+					for (VXGroup group : vXGroupList.getList()) {
+						if (listGroupId.contains(group.getId())) {
+							updatedList.add(group);
+						}
+					}
+					logger.info("Logged-In user having user role will be able to fetch his own groups details.");
+					vXGroupList.setVXGroups(updatedList);
+
+				}
+			}
+		}
+		
+		
 		if(vXGroupList!=null && !hasAccessToModule(RangerConstants.MODULE_USER_GROUPS)){
 			if(vXGroupList!=null && vXGroupList.getListSize()>0){
 				List<VXGroup> listMasked=new ArrayList<VXGroup>();
@@ -2255,7 +2333,7 @@ public class XUserMgr extends XUserMgrBase {
 		}
 		return createdXUser;
         }
-        private void validatePassword(VXUser vXUser) {
+        protected void validatePassword(VXUser vXUser) {
                 if (vXUser.getPassword() != null && !vXUser.getPassword().isEmpty()) {
                         boolean checkPassword = false;
                         String pattern = "(?=.*[0-9])(?=.*[a-zA-Z]).{8,}";
