@@ -28,7 +28,9 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.utils.StringUtil;
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXServiceResource;
+import org.springframework.stereotype.Service;
 
+@Service
 public class XXServiceResourceDao extends BaseDao<XXServiceResource> {
 
 	public XXServiceResourceDao(RangerDaoManagerBase daoManager) {
