@@ -26,7 +26,9 @@ import javax.persistence.NoResultException;
 
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXTagAttribute;
+import org.springframework.stereotype.Service;
 
+@Service
 public class XXTagAttributeDao extends BaseDao<XXTagAttribute> {
 
 	public XXTagAttributeDao(RangerDaoManagerBase daoManager) {
