@@ -390,13 +390,13 @@ public class DbToSolrMigrationUtil extends BaseLoader {
 					.getProperty("ranger.solr.url");
 		}
 
-		if (zkHosts != null && !zkHosts.trim().equals("")
-				&& !zkHosts.trim().equalsIgnoreCase("none")) {
+		if (zkHosts != null && !"".equals(zkHosts.trim())
+				&& !"none".equalsIgnoreCase(zkHosts.trim())) {
 			zkHosts = zkHosts.trim();
 			String collectionName = PropertiesUtil
 					.getProperty(SOLR_COLLECTION_NAME);
 			if (collectionName == null
-					|| collectionName.equalsIgnoreCase("none")) {
+					|| "none".equalsIgnoreCase(collectionName)) {
 				collectionName = DEFAULT_COLLECTION_NAME;
 			}
 
@@ -420,7 +420,7 @@ public class DbToSolrMigrationUtil extends BaseLoader {
 			}
 		} else {
 			if (solrURL == null || solrURL.isEmpty()
-					|| solrURL.equalsIgnoreCase("none")) {
+					|| "none".equalsIgnoreCase(solrURL)) {
 				logger.fatal("Solr ZKHosts and URL for Audit are empty. Please set property "
 						+ SOLR_ZK_HOSTS
 						+ " or "
@@ -435,7 +435,6 @@ public class DbToSolrMigrationUtil extends BaseLoader {
 								.setAllowCompression(true);
 						httpSolrClient
 								.setConnectionTimeout(1000);
-						httpSolrClient.setMaxRetries(1);
 						httpSolrClient
 								.setRequestWriter(new BinaryRequestWriter());
 						}
