@@ -23,6 +23,7 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.ranger.biz.AssetMgr;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.ServiceDBStore;
 import org.apache.ranger.biz.TagDBStore;
@@ -30,6 +31,7 @@ import org.apache.ranger.common.RESTErrorUtil;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXServiceDef;
+import org.apache.ranger.plugin.model.RangerPluginInfo;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceResource;
 import org.apache.ranger.plugin.model.RangerTag;
@@ -48,8 +50,19 @@ import org.springframework.transaction.annotation.Propagation;
 import org.springframework.transaction.annotation.Transactional;
 
 import javax.annotation.PostConstruct;
+import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import javax.ws.rs.*;
+import javax.ws.rs.DELETE;
+import javax.ws.rs.DefaultValue;
+import javax.ws.rs.GET;
+import javax.ws.rs.POST;
+import javax.ws.rs.PUT;
+import javax.ws.rs.Path;
+import javax.ws.rs.PathParam;
+import javax.ws.rs.Produces;
+import javax.ws.rs.QueryParam;
+import javax.ws.rs.WebApplicationException;
+import javax.ws.rs.core.Context;
 
 import java.util.List;
 
@@ -77,6 +90,9 @@ public class TagREST {
 	@Autowired
 	RangerBizUtil bizUtil;
 
+    @Autowired
+    AssetMgr assetMgr;
+
     TagValidator validator;
 
     public TagREST() {
@@ -1006,7 +1022,7 @@ public class TagREST {
         if(LOG.isDebugEnabled()) {
             LOG.debug("==> TagREST.getTagResourceMap(" + tagGuid + ", " + resourceGuid + ")");
         }
-        
+
         RangerTagResourceMap ret = null;
 
         try {
@@ -1088,51 +1104,62 @@ public class TagREST {
     @Path(TagRESTConstants.TAGS_DOWNLOAD + "{serviceName}")
     @Produces({ "application/json", "application/xml" })
     public ServiceTags getServiceTagsIfUpdated(@PathParam("serviceName") String serviceName,
-                                                   @QueryParam(TagRESTConstants.LAST_KNOWN_TAG_VERSION_PARAM) Long lastKnownVersion, @QueryParam("pluginId") String pluginId) {
+                                                   @QueryParam(TagRESTConstants.LAST_KNOWN_TAG_VERSION_PARAM) Long lastKnownVersion,
+                                               @DefaultValue("0") @QueryParam(TagRESTConstants.LAST_ACTIVATION_TIME) Long lastActivationTime, @QueryParam("pluginId") String pluginId,
+                                               @Context HttpServletRequest request) {
         if(LOG.isDebugEnabled()) {
-            LOG.debug("==> TagREST.getServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + pluginId + ")");
+            LOG.debug("==> TagREST.getServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + lastActivationTime + ", " + pluginId + ")");
         }
 
 		ServiceTags ret      = null;
 		int         httpCode = HttpServletResponse.SC_OK;
 		String      logMsg   = null;
+        Long downloadedVersion = null;
 
         try {
             ret = tagStore.getServiceTagsIfUpdated(serviceName, lastKnownVersion);
 
-			if(ret == null) {
-				httpCode = HttpServletResponse.SC_NOT_MODIFIED;
-				logMsg   = "No change since last update";
-			} else {
-				httpCode = HttpServletResponse.SC_OK;
-				logMsg   = "Returning " + (ret.getTags() != null ? ret.getTags().size() : 0) + " tags. Tag version=" + ret.getTagVersion();
-			}
+            if (ret == null) {
+                downloadedVersion = lastKnownVersion;
+                httpCode = HttpServletResponse.SC_NOT_MODIFIED;
+                logMsg = "No change since last update";
+            } else {
+                downloadedVersion = ret.getTagVersion();
+                httpCode = HttpServletResponse.SC_OK;
+                logMsg = "Returning " + (ret.getTags() != null ? ret.getTags().size() : 0) + " tags. Tag version=" + ret.getTagVersion();
+            }
+        } catch (WebApplicationException webException) {
+            httpCode = webException.getResponse().getStatus();
+            logMsg = webException.getResponse().getEntity().toString();
         } catch(Exception excp) {
-            LOG.error("getServiceTagsIfUpdated(" + serviceName + ") failed", excp);
-
 			httpCode = HttpServletResponse.SC_BAD_REQUEST;
 			logMsg   = excp.getMessage();
+        } finally {
+            assetMgr.createPluginInfo(serviceName, pluginId, request, RangerPluginInfo.ENTITY_TYPE_TAGS, downloadedVersion, lastKnownVersion, lastActivationTime, httpCode);
         }
 
-		if(httpCode != HttpServletResponse.SC_OK) {
-			boolean logError = httpCode != HttpServletResponse.SC_NOT_MODIFIED;
-			throw restErrorUtil.createRESTException(httpCode, logMsg, logError);
-		}
+        if(httpCode != HttpServletResponse.SC_OK) {
+            boolean logError = httpCode != HttpServletResponse.SC_NOT_MODIFIED;
+            throw restErrorUtil.createRESTException(httpCode, logMsg, logError);
+        }
 
         if(LOG.isDebugEnabled()) {
-            LOG.debug("<==> TagREST.getServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + pluginId + ")");
+            LOG.debug("<== TagREST.getServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + lastActivationTime + ", " + pluginId + ")");
         }
 
         return ret;
     }
-    
+
     @GET
     @Path(TagRESTConstants.TAGS_SECURE_DOWNLOAD + "{serviceName}")
     @Produces({ "application/json", "application/xml" })
     public ServiceTags getSecureServiceTagsIfUpdated(@PathParam("serviceName") String serviceName,
-                                                   @QueryParam(TagRESTConstants.LAST_KNOWN_TAG_VERSION_PARAM) Long lastKnownVersion, @QueryParam("pluginId") String pluginId) {
+                                                   @QueryParam(TagRESTConstants.LAST_KNOWN_TAG_VERSION_PARAM) Long lastKnownVersion,
+                                                     @DefaultValue("0") @QueryParam(TagRESTConstants.LAST_ACTIVATION_TIME) Long lastActivationTime, @QueryParam("pluginId") String pluginId,
+                                                     @Context HttpServletRequest request) {
+
         if(LOG.isDebugEnabled()) {
-            LOG.debug("==> TagREST.getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + pluginId + ")");
+            LOG.debug("==> TagREST.getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + lastActivationTime + ", " + pluginId + ")");
         }
 
 		ServiceTags ret      = null;
@@ -1141,9 +1168,15 @@ public class TagREST {
 		boolean isAllowed = false;
 		boolean isAdmin = bizUtil.isAdmin();
 		boolean isKeyAdmin = bizUtil.isKeyAdmin();
+        Long downloadedVersion = null;
 
         try {
         	XXService xService = daoManager.getXXService().findByName(serviceName);
+        	if (xService == null) {
+                LOG.error("Requested Service not found. serviceName=" + serviceName);
+                throw restErrorUtil.createRESTException(HttpServletResponse.SC_NOT_FOUND, "Service:" + serviceName + " not found",
+                        false);
+            }
         	XXServiceDef xServiceDef = daoManager.getXXServiceDef().getById(xService.getType());
         	RangerService rangerService = svcStore.getServiceByName(serviceName);
         	
@@ -1162,35 +1195,41 @@ public class TagREST {
         	}
         	if (isAllowed) {
 	            ret = tagStore.getServiceTagsIfUpdated(serviceName, lastKnownVersion);
-	
+
 				if(ret == null) {
+                    downloadedVersion = lastKnownVersion;
 					httpCode = HttpServletResponse.SC_NOT_MODIFIED;
 					logMsg   = "No change since last update";
 				} else {
+                    downloadedVersion = ret.getTagVersion();
 					httpCode = HttpServletResponse.SC_OK;
 					logMsg   = "Returning " + (ret.getTags() != null ? ret.getTags().size() : 0) + " tags. Tag version=" + ret.getTagVersion();
 				}
 			}else{
-				LOG.error("getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ") failed as User doesn't have permission to download tags");
+				LOG.error("getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + lastActivationTime + ") failed as User doesn't have permission to download tags");
 				httpCode = HttpServletResponse.SC_UNAUTHORIZED;
 				logMsg = "User doesn't have permission to download tags";
 			}
-        } catch(Exception excp) {
-            LOG.error("getSecureServiceTagsIfUpdated(" + serviceName + ") failed", excp);
-
+        } catch (WebApplicationException webException) {
+            httpCode = webException.getResponse().getStatus();
+            logMsg = webException.getResponse().getEntity().toString();
+        } catch (Exception excp) {
 			httpCode = HttpServletResponse.SC_BAD_REQUEST;
 			logMsg   = excp.getMessage();
+        }  finally {
+            assetMgr.createPluginInfo(serviceName, pluginId, request, RangerPluginInfo.ENTITY_TYPE_TAGS, downloadedVersion, lastKnownVersion, lastActivationTime, httpCode);
         }
 
-		if(httpCode != HttpServletResponse.SC_OK) {
-			boolean logError = httpCode != HttpServletResponse.SC_NOT_MODIFIED;
-			throw restErrorUtil.createRESTException(httpCode, logMsg, logError);
-		}
+        if(httpCode != HttpServletResponse.SC_OK) {
+            boolean logError = httpCode != HttpServletResponse.SC_NOT_MODIFIED;
+            throw restErrorUtil.createRESTException(httpCode, logMsg, logError);
+        }
 
         if(LOG.isDebugEnabled()) {
-            LOG.debug("<==> TagREST.getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + pluginId + ")");
+            LOG.debug("<== TagREST.getSecureServiceTagsIfUpdated(" + serviceName + ", " + lastKnownVersion + ", " + lastActivationTime + ", " + pluginId + ")");
         }
 
         return ret;
     }
+
 }
