@@ -21,7 +21,6 @@
 
 import java.util.HashMap;
 import java.util.List;
-import java.util.Random;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.DELETE;
@@ -35,15 +34,18 @@ import javax.ws.rs.core.Context;
 
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
+import org.apache.log4j.Logger;
 import org.apache.ranger.biz.RangerBizUtil;
 import org.apache.ranger.biz.SessionMgr;
 import org.apache.ranger.biz.XUserMgr;
+import org.apache.ranger.common.ContextUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.RESTErrorUtil;
 import org.apache.ranger.common.RangerConstants;
 import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.SearchUtil;
 import org.apache.ranger.common.StringUtil;
+import org.apache.ranger.common.UserSessionBase;
 import org.apache.ranger.common.annotation.RangerAnnotationClassName;
 import org.apache.ranger.common.annotation.RangerAnnotationJSMgrName;
 import org.apache.ranger.db.RangerDaoManager;
@@ -125,6 +127,11 @@ public class XUserREST {
 	
 	@Autowired
 	XResourceService xResourceService;
+	
+	@Autowired
+	StringUtil stringUtil;
+	
+	static final Logger logger = Logger.getLogger(XUserMgr.class);
 
 	// Handle XGroup
 	@GET
@@ -218,8 +225,8 @@ public class XUserREST {
 				request, xGroupService.sortFields);
 		searchUtil.extractString(request, searchCriteria, "name", "group name", null);
 		searchUtil.extractInt(request, searchCriteria, "isVisible", "Group Visibility");
-		searchUtil.extractString(request, searchCriteria, "groupSource", "group source", null);
-//		searchUtil.extractInt(request, searchCriteria, "groupSource", "group source");
+//		searchUtil.extractString(request, searchCriteria, "groupSource", "group source", null);
+		searchUtil.extractInt(request, searchCriteria, "groupSource", "group source");
 		return xUserMgr.searchXGroups(searchCriteria);
 	}
 
@@ -342,7 +349,8 @@ public class XUserREST {
 		searchUtil.extractInt(request, searchCriteria, "status", "User Status");
 		List<String> userRolesList = searchUtil.extractStringList(request, searchCriteria, "userRoleList", "User Role List", "userRoleList", null,
 				null);
-		searchUtil.extractString(request, searchCriteria, "userRole", "UserRole", null);
+		searchUtil.extractRoleString(request, searchCriteria, "userRole", "Role", null);
+
 		if (CollectionUtils.isNotEmpty(userRolesList) && CollectionUtils.size(userRolesList) == 1 && userRolesList.get(0).equalsIgnoreCase(UserRoleParamName)) {
 			if (!(searchCriteria.getParamList().containsKey("name"))) {
 				searchCriteria.addParam("name", userName);
@@ -350,9 +358,27 @@ public class XUserREST {
 			else if ((searchCriteria.getParamList().containsKey("name")) && userName!= null && userName.contains((String) searchCriteria.getParamList().get("name"))) {
 				searchCriteria.addParam("name", userName);
 			}
-			else {
-				String randomString = new Random().toString();
-				searchCriteria.addParam("name", randomString);
+		}
+		
+		
+		UserSessionBase userSession = ContextUtil.getCurrentUserSession();
+		if (userSession != null && userSession.getLoginId() != null) {
+			VXUser loggedInVXUser = xUserService.getXUserByUserName(userSession
+					.getLoginId());
+			if (loggedInVXUser != null) {
+				if (loggedInVXUser.getUserRoleList().size() == 1
+						&& loggedInVXUser.getUserRoleList().contains(
+								RangerConstants.ROLE_USER)) {
+					logger.info("Logged-In user having user role will be able to fetch his own user details.");
+					if (!searchCriteria.getParamList().containsKey("name")) {
+						searchCriteria.addParam("name", loggedInVXUser.getName());
+					}else if(searchCriteria.getParamList().containsKey("name")
+							&& !stringUtil.isEmpty(searchCriteria.getParamValue("name").toString())
+							&& !searchCriteria.getParamValue("name").toString().equalsIgnoreCase(loggedInVXUser.getName())){
+						throw restErrorUtil.create403RESTException("Logged-In user is not allowed to access requested user data.");
+					}
+									
+				}
 			}
 		}
 
