@@ -52,6 +52,8 @@ public class RangerAPIList {
 	public static final String GET_ACCESS_LOGS = "AssetREST.getAccessLogs";
 	public static final String GRANT_PERMISSION = "AssetREST.grantPermission";
 	public static final String REVOKE_PERMISSION = "AssetREST.revokePermission";
+	public static final String GET_UGSYNC_AUDITS = "AssetREST.getUgsyncAudits";
+	public static final String GET_UGSYNC_AUDITS_BY_SYNCSOURCE = "AssetREST.getUgsyncAuditsBySyncSource";
 
 	/**
 	 * List of APIs for ServiceREST
@@ -86,7 +88,7 @@ public class RangerAPIList {
 	public static final String GET_POLICY_VERSION_LIST = "ServiceREST.getPolicyVersionList";
 	public static final String GET_POLICY_FOR_VERSION_NO = "ServiceREST.getPolicyForVersionNumber";
 	public static final String GET_PLUGINS_INFO = "ServiceREST.getPluginsInfo";
-
+        public static final String GET_METRICS_BY_TYPE = "ServiceREST.getMetricByType";
 
 
 	/**
@@ -206,4 +208,4 @@ public class RangerAPIList {
 	public static final String SET_USER_ROLES_BY_NAME="XUserREST.setUserRolesByName";
 	public static final String GET_USER_ROLES_BY_ID="XUserREST.getUserRolesByID";
 	public static final String GET_USER_ROLES_BY_NAME="XUserREST.getUserRolesByName";
-}
\ No newline at end of file
+}
