@@ -556,19 +556,19 @@ public class RangerKRBAuthenticationFilter extends RangerKrbFilter {
 		}
 
 		@Override
-		public javax.servlet.ServletRegistration.Dynamic addServlet(
+		public ServletRegistration.Dynamic addServlet(
 				String servletName, Class<? extends Servlet> servletClass) {
 			return null;
 		}
 
 		@Override
-		public javax.servlet.ServletRegistration.Dynamic addServlet(
+		public ServletRegistration.Dynamic addServlet(
 				String servletName, Servlet servlet) {
 			return null;
 		}
 
 		@Override
-		public javax.servlet.ServletRegistration.Dynamic addServlet(
+		public ServletRegistration.Dynamic addServlet(
 				String servletName, String className) {
 			return null;
 		}
