@@ -138,16 +138,16 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 	}
 	
 	public List<XXTrxLog> getTransactionLog(RangerPolicy vPolicy, int action) {
-		return getTransactionLog(vPolicy, null, action);
+		return getTransactionLog(vPolicy, null, null, action);
 	}
 
-	public List<XXTrxLog> getTransactionLog(RangerPolicy vObj, XXPolicy mObj, int action) {
+	public List<XXTrxLog> getTransactionLog(RangerPolicy vObj, XXPolicy mObj, RangerPolicy oldPolicy, int action) {
 		if (vObj == null || action == 0 || (action == OPERATION_UPDATE_CONTEXT && mObj == null)) {
 			return null;
 		}
 		List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
 		Field[] fields = vObj.getClass().getDeclaredFields();
-		
+
 		try {
 			
 			Field nameField = vObj.getClass().getDeclaredField("name");
@@ -157,7 +157,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 				if (!trxLogAttrs.containsKey(field.getName())) {
 					continue;
 				}
-				XXTrxLog xTrxLog = processFieldToCreateTrxLog(field, objectName, nameField, vObj, mObj, action);
+				XXTrxLog xTrxLog = processFieldToCreateTrxLog(field, objectName, vObj, mObj, oldPolicy, action);
 				if (xTrxLog != null) {
 					trxLogList.add(xTrxLog);
 				}
@@ -167,7 +167,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 					.getDeclaredFields();
 			for (Field field : superClassFields) {
 				if ("isEnabled".equalsIgnoreCase(field.getName())) {
-					XXTrxLog xTrx = processFieldToCreateTrxLog(field, objectName, nameField, vObj, mObj, action);
+					XXTrxLog xTrx = processFieldToCreateTrxLog(field, objectName, vObj, mObj, oldPolicy, action);
 					if (xTrx != null) {
 						trxLogList.add(xTrx);
 					}
@@ -184,7 +184,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 	}
 	
 	private XXTrxLog processFieldToCreateTrxLog(Field field, String objectName,
-			Field nameField, RangerPolicy vObj, XXPolicy mObj, int action) {
+			RangerPolicy vObj, XXPolicy mObj, RangerPolicy oldPolicy, int action) {
 
 		String actionString = "";
 
@@ -199,54 +199,56 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 
 			String value = null;
 			boolean isEnum = vTrxLogAttr.isEnum();
-			if (isEnum) {
-
-			} else if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyResourcesForTrxLog(field.get(vObj));
-			} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (POLICY_NAME_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyNameForTrxLog(field.get(vObj));
-			} else if (ALLOW_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (DENY_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processDataMaskPolicyItemsForTrxLog(field.get(vObj));
-				if(vObj.getDataMaskPolicyItems() != null && CollectionUtils.isNotEmpty(vObj.getDataMaskPolicyItems())) {
-					for(RangerDataMaskPolicyItem policyItem : vObj.getDataMaskPolicyItems()) {
-						if(policyItem.getDataMaskInfo() != null && policyItem.getDataMaskInfo().getDataMaskType() != null) {
-							List<XXDataMaskTypeDef> xDataMaskDef = daoMgr.getXXDataMaskTypeDef().getAll();
-							if(CollectionUtils.isNotEmpty(xDataMaskDef) && xDataMaskDef != null ) {
-								for (XXDataMaskTypeDef xxDataMaskTypeDef : xDataMaskDef) {
-									if(xxDataMaskTypeDef.getName().equalsIgnoreCase(policyItem.getDataMaskInfo().getDataMaskType())) {
-										String label = xxDataMaskTypeDef.getLabel();
-										StringBuilder sbValue = new StringBuilder(value);
-										label = ",\"DataMasklabel\":\""+label+"\"";
-										int sbValueIndex = sbValue.lastIndexOf("}]");
-										sbValue.insert(sbValueIndex, label);
-										value = sbValue.toString();
-										break;
-									}
-								}
-							}
-						}
-					}
-				}
-			} else if (ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processRowFilterPolicyItemForTrxLog(field.get(vObj));
-			} else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = String.valueOf(processIsEnabledClassFieldNameForTrxLog(field.get(vObj)));
-                        } else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-                                value = processPolicyLabelsClassFieldNameForTrxLog(field.get(vObj));
-			} else if (POLICY_VALIDITYSCHEDULES_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processValiditySchedulesClassFieldNameForTrxLog(field.get(vObj));
-			} else if (POLICY_PRIORITY_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-				value = processPriorityClassFieldNameForTrxLog(field.get(vObj));
-			} else {
-				value = "" + field.get(vObj);
+			if (!isEnum) {
+			    if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyResourcesForTrxLog(field.get(vObj));
+    			} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyItemsForTrxLog(field.get(vObj));
+    			} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyItemsForTrxLog(field.get(vObj));
+    			} else if (POLICY_NAME_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyNameForTrxLog(field.get(vObj));
+    			} else if (ALLOW_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyItemsForTrxLog(field.get(vObj));
+    			} else if (DENY_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPolicyItemsForTrxLog(field.get(vObj));
+    			} else if (DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processDataMaskPolicyItemsForTrxLog(field.get(vObj));
+    				if(vObj.getDataMaskPolicyItems() != null && CollectionUtils.isNotEmpty(vObj.getDataMaskPolicyItems())) {
+    					for(RangerDataMaskPolicyItem policyItem : vObj.getDataMaskPolicyItems()) {
+    						if(policyItem.getDataMaskInfo() != null && policyItem.getDataMaskInfo().getDataMaskType() != null) {
+    							List<XXDataMaskTypeDef> xDataMaskDef = daoMgr.getXXDataMaskTypeDef().getAll();
+    							if(CollectionUtils.isNotEmpty(xDataMaskDef) && xDataMaskDef != null ) {
+    								for (XXDataMaskTypeDef xxDataMaskTypeDef : xDataMaskDef) {
+    									if(xxDataMaskTypeDef.getName().equalsIgnoreCase(policyItem.getDataMaskInfo().getDataMaskType())) {
+    										String label = xxDataMaskTypeDef.getLabel();
+    										StringBuilder sbValue = new StringBuilder(value);
+    										label = ",\"DataMasklabel\":\""+label+"\"";
+    										int sbValueIndex = sbValue.lastIndexOf("}]");
+    										sbValue.insert(sbValueIndex, label);
+    										value = sbValue.toString();
+    										break;
+    									}
+    								}
+    							}
+    						}
+    					}
+    				}
+    			} else if (ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processRowFilterPolicyItemForTrxLog(field.get(vObj));
+				} else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					value = processIsEnabledClassFieldNameForTrxLog(field.get(vObj));
+				} else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					value = processPolicyLabelsClassFieldNameForTrxLog(field.get(vObj));
+				} else if (POLICY_VALIDITYSCHEDULES_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					value = processValiditySchedulesClassFieldNameForTrxLog(field.get(vObj));
+				} else if (POLICY_PRIORITY_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+    				value = processPriorityClassFieldNameForTrxLog(field.get(vObj));
+				} else if (IS_AUDIT_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					value = processIsAuditEnabledClassFieldNameForTrxLog(field.get(vObj));
+    			} else {
+    				value = "" + field.get(vObj);
+    			}
 			}
 
 			if (action == OPERATION_CREATE_CONTEXT) {
@@ -266,15 +268,12 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 					mField.setAccessible(true);
 					String mFieldName = mField.getName();
 					if (fieldName.equalsIgnoreCase(mFieldName)) {
-						if (isEnum) {
-
-						} else {
+						if (!isEnum) {
 							oldValue = mField.get(mObj) + "";
 						}
 						break;
 					}
 				}
-				RangerPolicy oldPolicy = populateViewBean(mObj);
 				if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyResourcesForTrxLog(oldPolicy.getResources());
@@ -333,9 +332,13 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 					}
 				}else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
-						oldValue = String.valueOf(processIsEnabledClassFieldNameForTrxLog(oldPolicy.getIsEnabled()));
+						oldValue = processIsEnabledClassFieldNameForTrxLog(oldPolicy.getIsEnabled());
 					}
-				} else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+				} else if (IS_AUDIT_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					if (oldPolicy != null) {
+						oldValue = processIsAuditEnabledClassFieldNameForTrxLog(oldPolicy.getIsAuditEnabled());
+					}
+				}else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					oldValue = processPolicyLabelsClassFieldNameForTrxLog(oldPolicy.getPolicyLabels());
 				} else if (POLICY_VALIDITYSCHEDULES_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					oldValue = processValiditySchedulesClassFieldNameForTrxLog(oldPolicy.getValiditySchedules());
@@ -402,11 +405,11 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 					    return null;
 					}
 				} else if (IS_AUDIT_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-                                        if (compareTwoPolicyName(value, oldValue)) {
-                                                return null;
-                                        }
-                                } else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
-                                        if (compareTwoPolicyLabelList(value, oldValue)) {
+					if (compareTwoPolicyName(value, oldValue)) {
+						return null;
+					}
+				} else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					if (compareTwoPolicyLabelList(value, oldValue)) {
 						return null;
 					}
 				}
@@ -667,6 +670,13 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			return isEnabled;
 	}
 
+	private String processIsAuditEnabledClassFieldNameForTrxLog(Object value) {
+		if(value == null)
+			return null;
+		String isAuditEnabled = String.valueOf(value);
+		return isAuditEnabled;
+	}
+
 	private boolean compareTwoDataMaskingPolicyItemList(String value, String oldValue) {
 		if (value == null && oldValue == null) {
 			return true;
