@@ -19,33 +19,32 @@
 
  package org.apache.ranger.service;
 
+import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.hadoop.constants.RangerHadoopConstants;
+import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.SearchField;
 import org.apache.ranger.common.SearchField.DATA_TYPE;
 import org.apache.ranger.common.SearchField.SEARCH_TYPE;
 import org.apache.ranger.common.SortField;
 import org.apache.ranger.common.SortField.SORT_ORDER;
-import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.entity.XXAccessAudit;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXServiceDef;
 import org.apache.ranger.view.VXAccessAudit;
 import org.apache.ranger.view.VXAccessAuditList;
-import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Scope;
 import org.springframework.stereotype.Service;
 
 @Service
 @Scope("singleton")
 public class XAccessAuditService extends XAccessAuditServiceBase<XXAccessAudit, VXAccessAudit>{
+
 	public static final String NAME = "XAccessAudit";
-	@Autowired
-	RangerDaoManager appDaoMgr;
 	protected final String distinctCountQueryStr;
 	protected final String distinctQueryStr;
 
@@ -163,7 +162,7 @@ public class XAccessAuditService extends XAccessAuditServiceBase<XXAccessAudit,
 
         List<XXAccessAudit> resultList = (List<XXAccessAudit>) searchResources(searchCriteria,
                 searchFields, sortFields, returnList);
-
+        final boolean hiveQueryVisibility = PropertiesUtil.getBooleanProperty("ranger.audit.hive.query.visibility", true);
         // Iterate over the result list and create the return list
         for (XXAccessAudit gjXAccessAudit : resultList) {
             VXAccessAudit vXAccessAudit = populateViewBean(gjXAccessAudit);
@@ -172,7 +171,16 @@ public class XAccessAuditService extends XAccessAuditServiceBase<XXAccessAudit,
                 if(StringUtils.equalsIgnoreCase(vXAccessAudit.getAclEnforcer(), RangerHadoopConstants.DEFAULT_XASECURE_MODULE_ACL_NAME)) {
                     vXAccessAudit.setAclEnforcer(RangerHadoopConstants.DEFAULT_RANGER_MODULE_ACL_NAME);
                 }
-
+                                if (!hiveQueryVisibility && "hive".equalsIgnoreCase(vXAccessAudit.getServiceType())) {
+                                        vXAccessAudit.setRequestData(null);
+                                }
+                                else if("hive".equalsIgnoreCase(vXAccessAudit.getServiceType()) && ("grant".equalsIgnoreCase(vXAccessAudit.getAccessType()) || "revoke".equalsIgnoreCase(vXAccessAudit.getAccessType()))){
+                                        try {
+                                                vXAccessAudit.setRequestData(java.net.URLDecoder.decode(vXAccessAudit.getRequestData(), "UTF-8"));
+                                        } catch (UnsupportedEncodingException e) {
+                                                logger.warn("Error while encoding request data");
+                                        }
+                                }
                 xAccessAuditList.add(vXAccessAudit);
             }
         }
