@@ -1148,7 +1148,7 @@ define(function(require) {
 			var denyControllerActions = [], denyModulesObj = [];
 			var userModuleNames = _.pluck(vXPortalUser.get('userPermList'),'moduleName');
 			//add by default permission module to admin user
-			if (SessionMgr.isSystemAdmin()){
+                        if (XAUtils.isAuditorOrSystemAdmin(SessionMgr)){
 				userModuleNames.push('Permissions')
 			}
 			var groupModuleNames = _.pluck(vXPortalUser.get('groupPermissions'), 'moduleName'),
@@ -1216,16 +1216,23 @@ define(function(require) {
 		var SessionMgr  = require('mgrs/SessionMgr');
 		var userRoleList = []
 		_.each(XAEnums.UserRoles,function(val, key){
-			if(SessionMgr.isKeyAdmin() && XAEnums.UserRoles.ROLE_SYS_ADMIN.value != val.value){
+            if(SessionMgr.isKeyAdmin() && XAEnums.UserRoles.ROLE_SYS_ADMIN.value != val.value
+                && XAEnums.UserRoles.ROLE_ADMIN_AUDITOR.value != val.value){
 				userRoleList.push(key)
-			}else if(SessionMgr.isSystemAdmin() && XAEnums.UserRoles.ROLE_KEY_ADMIN.value != val.value){
+            }else if(SessionMgr.isSystemAdmin() && XAEnums.UserRoles.ROLE_KEY_ADMIN.value != val.value
+                && XAEnums.UserRoles.ROLE_KEY_ADMIN_AUDITOR.value != val.value){
 				userRoleList.push(key)
 			}else if(SessionMgr.isUser() && XAEnums.UserRoles.ROLE_USER.value == val.value){
 				userRoleList.push(key)
+            }else if(SessionMgr.isAuditor() && XAEnums.UserRoles.ROLE_KEY_ADMIN.value != val.value
+                && XAEnums.UserRoles.ROLE_KEY_ADMIN_AUDITOR.value != val.value){
+                userRoleList.push(key)
+            }else if(SessionMgr.isKMSAuditor() && XAEnums.UserRoles.ROLE_SYS_ADMIN.value != val.value
+                && XAEnums.UserRoles.ROLE_ADMIN_AUDITOR.value != val.value){
+                userRoleList.push(key)
 			}
 		})
-		return {'userRoleList' : userRoleList };
-	};
+		return {'userRoleList' : userRoleList };	};
 	XAUtils.showErrorMsg = function(respMsg){
 		var respArr = respMsg.split(/\([0-9]*\)/);
 		respArr = respArr.filter(function(str){ return str; });
@@ -1240,7 +1247,7 @@ define(function(require) {
 				}
 			var reason = str.lastIndexOf("reason") != -1 ? (str.substring(str.lastIndexOf("reason")+7, str.indexOf("field[")-3 ))
 					: str;
-			erroCodeMsg = erroCodeMsg != "" ? erroCodeMsg +"<br/>" : ""; 
+                        erroCodeMsg = erroCodeMsg != "" ? erroCodeMsg +"   " : "";
 			var erroMsg = erroCodeMsg +""+ XAUtils.capitaliseFirstLetter(reason);
 			return XAUtils.notifyError('Error', erroMsg);
 		});
@@ -1376,5 +1383,88 @@ define(function(require) {
         newLabelArr.push('</div>');
         return newLabelArr.length ? newLabelArr.join(' ') : '--';
     };
+    XAUtils.isAuditorOrSystemAdmin = function(SessionMgr){
+        return (SessionMgr.isAuditor() || SessionMgr.isSystemAdmin()) ? true : false ;
+    };
+    XAUtils.isAuditorOrKMSAuditor = function(SessionMgr){
+        return (SessionMgr.isAuditor() || SessionMgr.isKMSAuditor()) ? true : false ;
+    };
+    XAUtils.isPolicyExpierd = function(model){
+        var moment = require('moment');
+        var momontTz = require('momentTz');
+        return !_.some(model.get('validitySchedules') , function(m){
+            if(!m.endTime){
+                return true;
+            } else if(_.isEmpty(m.timeZone)){
+                return new Date().valueOf() > new Date(m.endTime).valueOf() ? false : true;
+            }else{
+                return new Date(moment.tz(m.timeZone).format('MM/DD/YYYY HH:mm:ss')).valueOf() >
+                new Date(m.endTime).valueOf() ? false : true;
+            }
+        });
+    };
+    XAUtils.copyToClipboard = function(e , copyText ){
+        var input = document.createElement('input');
+        if(_.isArray(copyText)){
+            input.setAttribute('value', copyText.join(' | '));
+        }else{
+            input.setAttribute('value', copyText);
+        }
+        document.body.appendChild(input);
+        input.select();
+        document.execCommand('copy');
+        document.body.removeChild(input);
+        e.currentTarget.title="Copied!";
+    };
+    //If view is closed, closed all new DOM element that added in DOM like popup, modal, date-selector and select-list etc.
+    XAUtils.removeUnwantedDomElement = function(){
+        $('.modal').remove();
+        $('.modal-backdrop').remove();
+        $('#select2-drop').select2('close');
+        $('.datepicker').remove();
+        $('.popover').remove();
+        $('.datetimepicker').remove();
+    };
+    //select2 option
+    XAUtils.select2OptionForUserCreateChoice = function(){
+        var opts = {
+                multiple: true,
+                data:[],
+                closeOnSelect : true,
+                width :'220px',
+                allowClear: true,
+                tokenSeparators: ["," , " "],
+                minimumInputLength: 1,
+                initSelection : function (element, callback) {
+                    var data = [];
+                    //to set single select value
+                    if(!_.isUndefined(opts.singleValueInput) && opts.singleValueInput){
+                        callback({ id : element.val(), text : element.val() });
+                        return;
+                    }
+                    //this is form multi-select value
+                    $(element.val().split(",")).each(function () {
+                        data.push({id: this, text: this});
+                    });
+                    callback(data);
+                },
+                createSearchChoice: function(term, data) {
+                    term = _.escape(term);
+                    if ($(data).filter(function() {
+                        return this.text.localeCompare(term) === 0;
+                    }).length === 0) {
+                        if($.inArray(term, this.val()) >= 0){
+                            return null;
+                        }else{
+                            return {
+                                id : term,
+                                text: term
+                            };
+                        }
+                    }
+                },
+            }
+        return opts;
+    }
 	return XAUtils;
 });
\ No newline at end of file
