@@ -23,7 +23,9 @@ define(function(require){
 
 	var Backbone		= require('backbone');
 
-	var TopNav_tmpl = require('hbs!tmpl/common/TopNav_tmpl'); 
+        var TopNav_tmpl = require('hbs!tmpl/common/TopNav_tmpl');
+        var SessionMgr  = require('mgrs/SessionMgr');
+        var XAUtil = require('utils/XAUtils');
 	require('jquery.cookie');
 	var TopNav = Backbone.Marionette.ItemView.extend(
 	/** @lends TopNav */
@@ -32,7 +34,9 @@ define(function(require){
 		
     	template: TopNav_tmpl,
     	templateHelpers : function(){
-    		
+        return{
+                showPermissionTab : XAUtil.isAuditorOrSystemAdmin(SessionMgr)
+		}
     	},
         
     	/** ui selector cache */
