@@ -131,13 +131,16 @@ define(function(require) {
 				}
 				_.each(this.model.get('accesses'), function(p){
 					if(p.isAllowed){
-						this.$el.find('input[data-name="' + p.type + '"]').attr('checked', 'checked');
+                                                this.$el.find('input[data-name="' + p.type + '"]').prop('checked', true);
 						_.each(this.accessItems,function(obj){ if(obj.type == p.type) obj.isAllowed=true;})
 					}
 				},this);
 				
 				if(!_.isUndefined(this.model.get('delegateAdmin')) && this.model.get('delegateAdmin')){
-					this.ui.delegatedAdmin.attr('checked', 'checked');
+                                        this.ui.delegatedAdmin.prop('checked', true);
+				}
+				if(this.model.has('delegateAdmin') && !this.model.get('delegateAdmin')){
+				    this.model.unset('delegateAdmin');
 				}
 				if(!_.isUndefined(this.model.get('rowFilterInfo')) && !_.isUndefined(this.model.get('rowFilterInfo').filterExpr)){
 					this.rowFilterExprVal = this.model.get('rowFilterInfo').filterExpr
@@ -166,8 +169,12 @@ define(function(require) {
 			var that = this;
 			$select.on('change',function(e){
 				var name = ($(e.currentTarget).attr('data-js') == that.ui.selectGroups.attr('data-js')) ? 'group': 'user';
+				var otherName = (name == 'user') ? 'group': 'user';
 				that.checkDirtyFieldForDropDown(e);
 				
+				if(_.isNull(that.model.get(otherName+'Name'))){
+                    that.model.unset(otherName+'Name')
+                }
 				if(e.removed != undefined){
 					var gNameArr = [];
 					if(that.model.get(name+'Name') != undefined)
@@ -228,7 +235,7 @@ define(function(require) {
 						return {results : results};
 					},
                     transport: function (options) {
-                    	$.ajax(options).error(function(respones) {
+			$.ajax(options).fail(function(respones) {
                     		XAUtil.defaultErrorHandler('error',respones);
                     		this.success({
                     			resultSize : 0
@@ -265,7 +272,9 @@ define(function(require) {
 			}
 			//if policy items not present. its skip that items and move forward
 			if(_.isObject(this.ui.addPerms)){
-				this.ui.addPerms.editable("destroy");
+                                if(changeType){
+                                    this.ui.addPerms.editable("destroy");
+                                }
 				//create x-editable for permissions
 				this.ui.addPerms.editable({
 					emptytext : 'Add Permissions',
@@ -304,10 +313,8 @@ define(function(require) {
                         that.ui.addPermissionsSpan.find('i').attr('class', 'icon-pencil');
                         that.ui.addPermissionsSpan.attr('title','edit');
 					},
-				}).on('click', function(e) {
-					e.stopPropagation();
-                    e.preventDefault();
-                    that.clickOnPermissions(that);
+                                }).on('shown', function(e, editable) {
+                                    that.clickOnPermissions(that);
 				});
 				that.ui.addPermissionsSpan.click(function(e) {
 				e.stopImmediatePropagation();
@@ -487,8 +494,8 @@ define(function(require) {
 					$(e.currentTarget).parent().find('.tag-fixed-popover-wrapper').remove()
 			}).on('click', function(e) {
 				e.stopPropagation();
-				e.preventDefault();
-				that.clickOnPermissions(that);
+//				e.preventDefault();
+//				that.clickOnPermissions(that);
 				 //Sticky popup
 				var pop = $(this).parent('td').find('.popover')
 				pop.wrap('<div class="tag-fixed-popover-wrapper"></div>');
@@ -511,7 +518,7 @@ define(function(require) {
 			var that = this, perms = [];
 			this.ui.addPerms.attr('data-type','radiolist')
 			this.ui.addPerms.attr('title','Components Permissions')
-			this.ui.delegatedAdmin.parent('td').hide();
+//			this.ui.delegatedAdmin.parent('td').hide();
 			
 			var maskingTypes = this.rangerServiceDefModel.get('dataMaskDef').maskTypes;
 			//get selected components masking types
@@ -528,14 +535,15 @@ define(function(require) {
 					maskTypeVal = $.inArray(maskTypeVal.substr(0,maskTypeVal.indexOf(":")), accessTypeSelectedComp) >= 0 ? maskTypeVal : [];
 				}
 			}
-			//Reset Add Masking Options
-			this.ui.maskingType.editable("setValue",null);
-			this.ui.maskingType.editable("destroy");
-			that.ui.addMaskingTypeSpan.unbind( "click" );
+                        if(accessTypeSelectedComp || _.isEmpty(accessTypeSelectedComp)){
+                            this.ui.maskingType.editable("destroy");
+                        }
+                        that.ui.addMaskingTypeSpan.unbind( "click" );
 			this.$el.find('input[data-id="maskTypeCustom"]').unbind( "change" );
 			that.ui.addMaskingTypeSpan.find('i').attr('class', 'icon-plus');
 			that.ui.addMaskingTypeSpan.attr('title','add');
-			this.$el.find('input[data-id="maskTypeCustom"]').css("display","none");
+                        this.$el.find('input[data-id="maskTypeCustom"]').css("display","none");
+
 			//create x-editable for permissions
 			this.ui.maskingType.editable({
 			    emptytext : 'Add Mask Type',
@@ -547,7 +555,6 @@ define(function(require) {
 				display: function(value,srcData) {
 					if(_.isNull(value) || _.isUndefined(value) || _.isEmpty(value)){
 						$(this).empty();
-//						that.model.unset('accesses');
 						that.ui.addPermissionsSpan.find('i').attr('class', 'icon-plus');
 						that.ui.addPermissionsSpan.attr('title','add');
 						return;
@@ -571,12 +578,13 @@ define(function(require) {
 				},
 			}).on('hide',function(e){
 					$(e.currentTarget).parent().find('.tag-fixed-popover-wrapper').remove()
-			}).on('click', function(e) {
-				e.stopPropagation();
-				e.preventDefault();
-			});
+                        }).on('click', function(e) {
+                            e.stopPropagation();
+                            e.preventDefault();
+                        });
 			that.ui.addMaskingTypeSpan.click(function(e) {
 				e.stopPropagation();
+                                 e.preventDefault();
 				if(!that.accessPermSetForTagMasking){
 					XAUtil.alertPopup({ msg :localization.tt('msg.pleaseSelectAccessTypeForTagMasking') });
 					return;
@@ -595,19 +603,20 @@ define(function(require) {
 		clickOnPermissions : function(that) {
 			var selectAll = true;
 			var checklist = that.$('.editable-checklist').find('input[type="checkbox"]')
-			
-			_.each(checklist,function(checkbox){ if($(checkbox).val() != -1 && !$(checkbox).is(':checked')) selectAll = false;})
+            _.each(checklist,function(checkbox){
+                if($(checkbox).val() != -1 && !$(checkbox).is(':checked'))
+                    selectAll = false;
+            })
 			if(selectAll){
 				that.$('.editable-checklist').find('input[type="checkbox"][value="-1"]').prop('checked',true)
 			} else {
 				that.$('.editable-checklist').find('input[type="checkbox"][value="-1"]').prop('checked',false)
 			}
 			//for selectAll functionality
-			that.$('input[type="checkbox"][value="-1"]').click(function(e){
-				var checkboxlist =$(this).closest('.editable-checklist').find('input[type="checkbox"][value!=-1]')
-				$(this).is(':checked') ? checkboxlist.prop('checked',true) : checkboxlist.prop('checked',false); 
-				
-			});
+                        that.$('input[type="checkbox"][value="-1"]').click(function(e){
+                var checkboxlist =$(this).closest('.editable-checklist').find('input[type="checkbox"][value!=-1]')
+                $(this).is(':checked') ? checkboxlist.prop('checked',true) : checkboxlist.prop('checked',false);
+            });
 			that.$('.editable-checklist input[type="checkbox"]').click(function(e){
 				if(this.value!="-1"){
 					var selectAll = true;
@@ -626,8 +635,16 @@ define(function(require) {
 			if(this.policyConditions.length > 0){
 				var tmpl = _.map(this.policyConditions,function(obj){
 					if(!_.isUndefined(obj.evaluatorOptions) && !_.isUndefined(obj.evaluatorOptions['ui.isMultiline']) && Boolean(obj.evaluatorOptions['ui.isMultiline'])){
-						return '<div class="editable-address margin-bottom-5"><label style="display:block !important;"><span>'+obj.label+' : </span><i title="JavaScript Condition Examples :\ncountry_code == \'USA\', time_range >= 900 && time_range <= 1800 etc." class="icon-info-sign" style="float: right;margin-top: 6px;"></i>\
-						</label><textarea name="'+obj.name+'" placeholder="Please enter condition.."></textarea></div>'
+						return '<div class="editable-address margin-bottom-5">\
+						            <label style="display:block !important;">\
+						                <span>'+obj.label+' : </span>\
+						                <i title="'+localization.tt('validationMessages.jsValidationMsg')+'" class="icon-info-sign" style="float: right;margin-top: 6px;"></i>\
+						            </label>\
+						            <textarea class="textAreaContainer" name="'+obj.name+'" placeholder="Please enter condition.."></textarea>\
+						            <div class="jsValidation">\
+						                <a href="javascript:;"class="jsValidationCheck btn btn-defult btn-mini" style="margin: 5px">Syntax check</a>\
+						            </div>\
+						       </div>'
 					}
 					return '<div class="editable-address margin-bottom-5"><label style="display:block !important;"><span>'+obj.label+' : </span></label><input type="text" name="'+obj.name+'" ></div>'
 						
@@ -690,7 +707,12 @@ define(function(require) {
 						}
 					},
 					validate:function(value){
-						var error = {'flag' : false};
+					    if(that.$el.find('.textAreaContainer').hasClass('errorClass') ||
+					            that.$el.find('.jsValidation span').hasClass('validSyntax')){
+					        that.$el.find('.textAreaContainer').removeClass('errorClass');
+					        that.$el.find('.jsValidation').find('span').remove();
+                        }
+					    var error = {'flag' : false};
 						_.each(value, function(val, name){
 							var tmp = _.findWhere(that.multiLinecond, { 'name' : name});
 							if(!_.isUndefined(tmp)){
@@ -713,12 +735,41 @@ define(function(require) {
 							return error.message;
 						}
 				    },
+				}).on('shown', function(e){
+				    that.$el.find('.jsValidationCheck').on('click',function(e){
+				        e.stopPropagation();
+				        var $textArea = $(e.currentTarget).parent().parent();
+				        if(that.$el.find('.editableform div.control-group').hasClass('error')){
+				            that.$el.find('.editableform div.control-group').removeClass('error');
+				            that.$el.find('.editable-error-block').remove();
+				        }
+				        if($textArea.find('.textAreaContainer').hasClass('errorClass') || $textArea.find('.jsValidation span').hasClass('validSyntax')){
+				            $textArea.find('.textAreaContainer').removeClass('errorClass');
+				            $textArea.find('.jsValidation').find('span').remove();
+				        }
+				        var tmp = $textArea.find('textarea').val();
+                        if(!_.isUndefined(tmp) && ! _.isEmpty(tmp)){
+				            var errorMessage;
+                            try {
+                                var t = esprima.parse(tmp);
+                            }catch(e){
+                                errorMessage = e.message;
+                            }
+                            if(!_.isUndefined(errorMessage)){
+                                $textArea.find('.textAreaContainer').addClass('errorClass');
+                                $textArea.find('.jsValidation').append('<span class="text-color-red">'+errorMessage+'</span>');
+                            }else{
+                                $textArea.find('.jsValidation').append('<span class="validSyntax">valid javascript condition</span>');
+                            }
+                        }
+				    })
 				});
 				that.ui.addConditionsSpan.click(function(e) {
 					e.stopPropagation();
 					that.$('#policyConditions').editable('toggle');
 				});
-				
+			}else{
+			    that.model.unset('conditions');
 			}
 		},
 		getSelectedValues : function($select, typeGroup){
@@ -739,8 +790,10 @@ define(function(require) {
 			var $el = $(e.currentTarget);
 			XAUtil.checkDirtyFieldForToggle($el);
 			//Set Delegated Admin value 
-			if(!_.isUndefined($el.find('input').data('js'))){
-				this.model.set('delegateAdmin',$el.is(':checked'));
+			if($el.is(':checked')){
+			    this.model.set('delegateAdmin',$el.is(':checked'));
+			}else{
+			    this.model.unset('delegateAdmin');
 			}
 			//select/deselect all functionality
 			if(this.checkAll($el.find('input[type="checkbox"][value!="-1"]'))){
